accesslog

package
v0.0.0-...-84cf697 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2018 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Package accesslog is a generated protocol buffer package.

It is generated from these files:

api/filter/accesslog/accesslog.proto

It has these top-level messages:

AccessLogCommon
ResponseFlags
TLSProperties
TCPAccessLogEntry
HTTPRequestProperties
HTTPResponseProperties
HTTPAccessLogEntry
AccessLog
AccessLogFilter
ComparisonFilter
StatusCodeFilter
DurationFilter
NotHealthCheckFilter
TraceableFilter
RuntimeFilter
AndFilter
OrFilter
FileAccessLog
TcpGrpcAccessLogConfig
HttpGrpcAccessLogConfig
CommonGrpcAccessLogConfig
StreamAccessLogsMessage
StreamAccessLogsResponse

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidLengthAccesslog = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowAccesslog   = fmt.Errorf("proto: integer overflow")
)
var ComparisonFilter_Op_name = map[int32]string{
	0: "EQ",
	1: "GE",
}
var ComparisonFilter_Op_value = map[string]int32{
	"EQ": 0,
	"GE": 1,
}
var HTTPAccessLogEntry_HTTPVersion_name = map[int32]string{
	0: "PROTOCOL_UNSPECIFIED",
	1: "HTTP10",
	2: "HTTP11",
	3: "HTTP2",
}
var HTTPAccessLogEntry_HTTPVersion_value = map[string]int32{
	"PROTOCOL_UNSPECIFIED": 0,
	"HTTP10":               1,
	"HTTP11":               2,
	"HTTP2":                3,
}
var TLSProperties_TLSVersion_name = map[int32]string{
	0: "VERSION_UNSPECIFIED",
	1: "TLSv1",
	2: "TLSv1_1",
	3: "TLSv1_2",
	4: "TLSv1_3",
}
var TLSProperties_TLSVersion_value = map[string]int32{
	"VERSION_UNSPECIFIED": 0,
	"TLSv1":               1,
	"TLSv1_1":             2,
	"TLSv1_2":             3,
	"TLSv1_3":             4,
}

Functions

func RegisterAccessLogServiceServer

func RegisterAccessLogServiceServer(s *grpc.Server, srv AccessLogServiceServer)

Types

type AccessLog

type AccessLog struct {
	// The name of the access log implementation to instantiate. The name must
	// match a statically registered access log. Current built-in loggers include:
	// 1) "envoy.file_access_log"
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Filter which is used to determine if the access log needs to be written.
	Filter *AccessLogFilter `protobuf:"bytes,2,opt,name=filter" json:"filter,omitempty"`
	// Custom configuration that depends on the access log being instantiated. built-in configurations
	// include:
	// 1) "envoy.file_access_log": :ref:`FileAccessLog <envoy_api_msg_filter.accesslog.FileAccessLog>`
	Config *google_protobuf4.Struct `protobuf:"bytes,3,opt,name=config" json:"config,omitempty"`
}

func (*AccessLog) Descriptor

func (*AccessLog) Descriptor() ([]byte, []int)

func (*AccessLog) GetConfig

func (m *AccessLog) GetConfig() *google_protobuf4.Struct

func (*AccessLog) GetFilter

func (m *AccessLog) GetFilter() *AccessLogFilter

func (*AccessLog) GetName

func (m *AccessLog) GetName() string

func (*AccessLog) Marshal

func (m *AccessLog) Marshal() (dAtA []byte, err error)

func (*AccessLog) MarshalTo

func (m *AccessLog) MarshalTo(dAtA []byte) (int, error)

func (*AccessLog) ProtoMessage

func (*AccessLog) ProtoMessage()

func (*AccessLog) Reset

func (m *AccessLog) Reset()

func (*AccessLog) Size

func (m *AccessLog) Size() (n int)

func (*AccessLog) String

func (m *AccessLog) String() string

func (*AccessLog) Unmarshal

func (m *AccessLog) Unmarshal(dAtA []byte) error

type AccessLogCommon

type AccessLogCommon struct {
	// This field indicates the rate at which this log entry was sampled.
	// Valid range is (0.0, 1.0].
	SampleRate float64 `protobuf:"fixed64,1,opt,name=sample_rate,json=sampleRate,proto3" json:"sample_rate,omitempty"`
	// This field is the remote/origin address on which the request from the user was received.
	// Note: This may not be the physical peer. E.g, if the remote address is inferred from for
	//       example the x-forwarder-for header, proxy protocol, etc.
	DownstreamRemoteAddress *envoy_api_v2.Address `protobuf:"bytes,2,opt,name=downstream_remote_address,json=downstreamRemoteAddress" json:"downstream_remote_address,omitempty"`
	// This field is the local/destination address on which the request from the user was received.
	DownstreamLocalAddress *envoy_api_v2.Address `protobuf:"bytes,3,opt,name=downstream_local_address,json=downstreamLocalAddress" json:"downstream_local_address,omitempty"`
	// If the connection is secure, this field will contain TLS properties.
	TlsProperties *TLSProperties `protobuf:"bytes,4,opt,name=tls_properties,json=tlsProperties" json:"tls_properties,omitempty"`
	// The time that Envoy started servicing this request. This is effectively the time that the first
	// downstream byte is received.
	StartTime *google_protobuf3.Timestamp `protobuf:"bytes,5,opt,name=start_time,json=startTime" json:"start_time,omitempty"`
	// Interval between the first downstream byte received and the last
	// downstream byte received (i.e. time it takes to receive a request).
	TimeToLastRxByte *google_protobuf2.Duration `protobuf:"bytes,6,opt,name=time_to_last_rx_byte,json=timeToLastRxByte" json:"time_to_last_rx_byte,omitempty"`
	// Interval between the first downstream byte received and the first upstream byte sent. There may
	// by considerable delta between *time_to_last_rx_byte* and this value due to filters.
	// Additionally, the same caveats apply as documented in *time_to_last_downstream_tx_byte* about
	// not accounting for kernel socket buffer time, etc.
	TimeToFirstUpstreamTxByte *google_protobuf2.Duration `` /* 137-byte string literal not displayed */
	// Interval between the first downstream byte received and the last upstream byte sent. There may
	// by considerable delta between *time_to_last_rx_byte* and this value due to filters.
	// Additionally, the same caveats apply as documented in *time_to_last_downstream_tx_byte* about
	// not accounting for kernel socket buffer time, etc.
	TimeToLastUpstreamTxByte *google_protobuf2.Duration `` /* 134-byte string literal not displayed */
	// Interval between the first downstream byte received and the first upstream
	// byte received (i.e. time it takes to start receiving a response).
	TimeToFirstUpstreamRxByte *google_protobuf2.Duration `` /* 137-byte string literal not displayed */
	// Interval between the first downstream byte received and the last upstream
	// byte received (i.e. time it takes to receive a complete response).
	TimeToLastUpstreamRxByte *google_protobuf2.Duration `` /* 135-byte string literal not displayed */
	// Interval between the first downstream byte received and the first downstream byte sent.
	// There may be a considerable delta between the *time_to_first_upstream_rx_byte* and this field
	// due to filters. Additionally, the same caveats apply as documented in
	// *time_to_last_downstream_tx_byte* about not accounting for kernel socket buffer time, etc.
	TimeToFirstDownstreamTxByte *google_protobuf2.Duration `` /* 144-byte string literal not displayed */
	// Interval between the first downstream byte received and the last downstream byte sent.
	// Depending on protocol, buffering, windowing, filters, etc. there may be a considerable delta
	// between *time_to_last_upstream_rx_byte* and this field. Note also that this is an approximate
	// time. In the current implementation it does not include kernel socket buffer time. In the
	// current implementation it also does not include send window buffering inside the HTTP/2 codec.
	// In the future it is likely that work will be done to make this duration more accurate.
	TimeToLastDownstreamTxByte *google_protobuf2.Duration `` /* 141-byte string literal not displayed */
	// The upstream remote/destination address that handles this exchange. This does not include
	// retries.
	UpstreamRemoteAddress *envoy_api_v2.Address `protobuf:"bytes,13,opt,name=upstream_remote_address,json=upstreamRemoteAddress" json:"upstream_remote_address,omitempty"`
	// The upstream local/origin address that handles this exchange. This does not include retries.
	UpstreamLocalAddress *envoy_api_v2.Address `protobuf:"bytes,14,opt,name=upstream_local_address,json=upstreamLocalAddress" json:"upstream_local_address,omitempty"`
	// The upstream cluster that *upstream_remote_address* belongs to.
	UpstreamCluster string `protobuf:"bytes,15,opt,name=upstream_cluster,json=upstreamCluster,proto3" json:"upstream_cluster,omitempty"`
	// Flags indicating occurences during request/response processing.
	ResponseFlags *ResponseFlags `protobuf:"bytes,16,opt,name=response_flags,json=responseFlags" json:"response_flags,omitempty"`
	// All metadata encountered during request processing, including endpoint
	// selection.
	//
	// This can be used to associate IDs attached to the various configurations
	// used to process this request with the access log entry. For example, a
	// route created from a higher level forwarding rule with some ID can place
	// that ID in this field and cross reference later. It can also be used to
	// determine if a canary endpoint was used or not.
	Metadata *envoy_api_v21.Metadata `protobuf:"bytes,17,opt,name=metadata" json:"metadata,omitempty"`
}

Defines fields that are shared by all Envoy access logs. [#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*AccessLogCommon) Descriptor

func (*AccessLogCommon) Descriptor() ([]byte, []int)

func (*AccessLogCommon) GetDownstreamLocalAddress

func (m *AccessLogCommon) GetDownstreamLocalAddress() *envoy_api_v2.Address

func (*AccessLogCommon) GetDownstreamRemoteAddress

func (m *AccessLogCommon) GetDownstreamRemoteAddress() *envoy_api_v2.Address

func (*AccessLogCommon) GetMetadata

func (m *AccessLogCommon) GetMetadata() *envoy_api_v21.Metadata

func (*AccessLogCommon) GetResponseFlags

func (m *AccessLogCommon) GetResponseFlags() *ResponseFlags

func (*AccessLogCommon) GetSampleRate

func (m *AccessLogCommon) GetSampleRate() float64

func (*AccessLogCommon) GetStartTime

func (m *AccessLogCommon) GetStartTime() *google_protobuf3.Timestamp

func (*AccessLogCommon) GetTimeToFirstDownstreamTxByte

func (m *AccessLogCommon) GetTimeToFirstDownstreamTxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToFirstUpstreamRxByte

func (m *AccessLogCommon) GetTimeToFirstUpstreamRxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToFirstUpstreamTxByte

func (m *AccessLogCommon) GetTimeToFirstUpstreamTxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToLastDownstreamTxByte

func (m *AccessLogCommon) GetTimeToLastDownstreamTxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToLastRxByte

func (m *AccessLogCommon) GetTimeToLastRxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToLastUpstreamRxByte

func (m *AccessLogCommon) GetTimeToLastUpstreamRxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTimeToLastUpstreamTxByte

func (m *AccessLogCommon) GetTimeToLastUpstreamTxByte() *google_protobuf2.Duration

func (*AccessLogCommon) GetTlsProperties

func (m *AccessLogCommon) GetTlsProperties() *TLSProperties

func (*AccessLogCommon) GetUpstreamCluster

func (m *AccessLogCommon) GetUpstreamCluster() string

func (*AccessLogCommon) GetUpstreamLocalAddress

func (m *AccessLogCommon) GetUpstreamLocalAddress() *envoy_api_v2.Address

func (*AccessLogCommon) GetUpstreamRemoteAddress

func (m *AccessLogCommon) GetUpstreamRemoteAddress() *envoy_api_v2.Address

func (*AccessLogCommon) Marshal

func (m *AccessLogCommon) Marshal() (dAtA []byte, err error)

func (*AccessLogCommon) MarshalTo

func (m *AccessLogCommon) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogCommon) ProtoMessage

func (*AccessLogCommon) ProtoMessage()

func (*AccessLogCommon) Reset

func (m *AccessLogCommon) Reset()

func (*AccessLogCommon) Size

func (m *AccessLogCommon) Size() (n int)

func (*AccessLogCommon) String

func (m *AccessLogCommon) String() string

func (*AccessLogCommon) Unmarshal

func (m *AccessLogCommon) Unmarshal(dAtA []byte) error

type AccessLogFilter

type AccessLogFilter struct {
	// Types that are valid to be assigned to FilterSpecifier:
	//	*AccessLogFilter_StatusCodeFilter
	//	*AccessLogFilter_DurationFilter
	//	*AccessLogFilter_NotHealthCheckFilter
	//	*AccessLogFilter_TraceableFilter
	//	*AccessLogFilter_RuntimeFilter
	//	*AccessLogFilter_AndFilter
	//	*AccessLogFilter_OrFilter
	FilterSpecifier isAccessLogFilter_FilterSpecifier `protobuf_oneof:"filter_specifier"`
}

func (*AccessLogFilter) Descriptor

func (*AccessLogFilter) Descriptor() ([]byte, []int)

func (*AccessLogFilter) GetAndFilter

func (m *AccessLogFilter) GetAndFilter() *AndFilter

func (*AccessLogFilter) GetDurationFilter

func (m *AccessLogFilter) GetDurationFilter() *DurationFilter

func (*AccessLogFilter) GetFilterSpecifier

func (m *AccessLogFilter) GetFilterSpecifier() isAccessLogFilter_FilterSpecifier

func (*AccessLogFilter) GetNotHealthCheckFilter

func (m *AccessLogFilter) GetNotHealthCheckFilter() *NotHealthCheckFilter

func (*AccessLogFilter) GetOrFilter

func (m *AccessLogFilter) GetOrFilter() *OrFilter

func (*AccessLogFilter) GetRuntimeFilter

func (m *AccessLogFilter) GetRuntimeFilter() *RuntimeFilter

func (*AccessLogFilter) GetStatusCodeFilter

func (m *AccessLogFilter) GetStatusCodeFilter() *StatusCodeFilter

func (*AccessLogFilter) GetTraceableFilter

func (m *AccessLogFilter) GetTraceableFilter() *TraceableFilter

func (*AccessLogFilter) Marshal

func (m *AccessLogFilter) Marshal() (dAtA []byte, err error)

func (*AccessLogFilter) MarshalTo

func (m *AccessLogFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter) ProtoMessage

func (*AccessLogFilter) ProtoMessage()

func (*AccessLogFilter) Reset

func (m *AccessLogFilter) Reset()

func (*AccessLogFilter) Size

func (m *AccessLogFilter) Size() (n int)

func (*AccessLogFilter) String

func (m *AccessLogFilter) String() string

func (*AccessLogFilter) Unmarshal

func (m *AccessLogFilter) Unmarshal(dAtA []byte) error

func (*AccessLogFilter) XXX_OneofFuncs

func (*AccessLogFilter) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})

XXX_OneofFuncs is for the internal use of the proto package.

type AccessLogFilter_AndFilter

type AccessLogFilter_AndFilter struct {
	AndFilter *AndFilter `protobuf:"bytes,6,opt,name=and_filter,json=andFilter,oneof"`
}

func (*AccessLogFilter_AndFilter) MarshalTo

func (m *AccessLogFilter_AndFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_AndFilter) Size

func (m *AccessLogFilter_AndFilter) Size() (n int)

type AccessLogFilter_DurationFilter

type AccessLogFilter_DurationFilter struct {
	DurationFilter *DurationFilter `protobuf:"bytes,2,opt,name=duration_filter,json=durationFilter,oneof"`
}

func (*AccessLogFilter_DurationFilter) MarshalTo

func (m *AccessLogFilter_DurationFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_DurationFilter) Size

func (m *AccessLogFilter_DurationFilter) Size() (n int)

type AccessLogFilter_NotHealthCheckFilter

type AccessLogFilter_NotHealthCheckFilter struct {
	NotHealthCheckFilter *NotHealthCheckFilter `protobuf:"bytes,3,opt,name=not_health_check_filter,json=notHealthCheckFilter,oneof"`
}

func (*AccessLogFilter_NotHealthCheckFilter) MarshalTo

func (m *AccessLogFilter_NotHealthCheckFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_NotHealthCheckFilter) Size

type AccessLogFilter_OrFilter

type AccessLogFilter_OrFilter struct {
	OrFilter *OrFilter `protobuf:"bytes,7,opt,name=or_filter,json=orFilter,oneof"`
}

func (*AccessLogFilter_OrFilter) MarshalTo

func (m *AccessLogFilter_OrFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_OrFilter) Size

func (m *AccessLogFilter_OrFilter) Size() (n int)

type AccessLogFilter_RuntimeFilter

type AccessLogFilter_RuntimeFilter struct {
	RuntimeFilter *RuntimeFilter `protobuf:"bytes,5,opt,name=runtime_filter,json=runtimeFilter,oneof"`
}

func (*AccessLogFilter_RuntimeFilter) MarshalTo

func (m *AccessLogFilter_RuntimeFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_RuntimeFilter) Size

func (m *AccessLogFilter_RuntimeFilter) Size() (n int)

type AccessLogFilter_StatusCodeFilter

type AccessLogFilter_StatusCodeFilter struct {
	StatusCodeFilter *StatusCodeFilter `protobuf:"bytes,1,opt,name=status_code_filter,json=statusCodeFilter,oneof"`
}

func (*AccessLogFilter_StatusCodeFilter) MarshalTo

func (m *AccessLogFilter_StatusCodeFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_StatusCodeFilter) Size

func (m *AccessLogFilter_StatusCodeFilter) Size() (n int)

type AccessLogFilter_TraceableFilter

type AccessLogFilter_TraceableFilter struct {
	TraceableFilter *TraceableFilter `protobuf:"bytes,4,opt,name=traceable_filter,json=traceableFilter,oneof"`
}

func (*AccessLogFilter_TraceableFilter) MarshalTo

func (m *AccessLogFilter_TraceableFilter) MarshalTo(dAtA []byte) (int, error)

func (*AccessLogFilter_TraceableFilter) Size

func (m *AccessLogFilter_TraceableFilter) Size() (n int)

type AccessLogServiceClient

type AccessLogServiceClient interface {
	// Envoy will connect and send StreamAccessLogsMessage messages forever. It does not expect any
	// response to be sent as nothing would be done in the case of failure. The server should
	// disconnect if it expects Envoy to reconnect. In the future we may decide to add a different
	// API for "critical" access logs in which Envoy will buffer access logs for some period of time
	// until it gets an ACK so it could then retry. This API is designed for high throughput with the
	// expectation that it might be lossy.
	StreamAccessLogs(ctx context.Context, opts ...grpc.CallOption) (AccessLogService_StreamAccessLogsClient, error)
}

func NewAccessLogServiceClient

func NewAccessLogServiceClient(cc *grpc.ClientConn) AccessLogServiceClient

type AccessLogServiceServer

type AccessLogServiceServer interface {
	// Envoy will connect and send StreamAccessLogsMessage messages forever. It does not expect any
	// response to be sent as nothing would be done in the case of failure. The server should
	// disconnect if it expects Envoy to reconnect. In the future we may decide to add a different
	// API for "critical" access logs in which Envoy will buffer access logs for some period of time
	// until it gets an ACK so it could then retry. This API is designed for high throughput with the
	// expectation that it might be lossy.
	StreamAccessLogs(AccessLogService_StreamAccessLogsServer) error
}

type AccessLogService_StreamAccessLogsClient

type AccessLogService_StreamAccessLogsClient interface {
	Send(*StreamAccessLogsMessage) error
	CloseAndRecv() (*StreamAccessLogsResponse, error)
	grpc.ClientStream
}

type AccessLogService_StreamAccessLogsServer

type AccessLogService_StreamAccessLogsServer interface {
	SendAndClose(*StreamAccessLogsResponse) error
	Recv() (*StreamAccessLogsMessage, error)
	grpc.ServerStream
}

type AndFilter

type AndFilter struct {
	Filters []*AccessLogFilter `protobuf:"bytes,1,rep,name=filters" json:"filters,omitempty"`
}

Performs a logical “and” operation on the result of each filter in filters. Filters are evaluated sequentially and if one of them returns false, the filter returns false immediately.

func (*AndFilter) Descriptor

func (*AndFilter) Descriptor() ([]byte, []int)

func (*AndFilter) GetFilters

func (m *AndFilter) GetFilters() []*AccessLogFilter

func (*AndFilter) Marshal

func (m *AndFilter) Marshal() (dAtA []byte, err error)

func (*AndFilter) MarshalTo

func (m *AndFilter) MarshalTo(dAtA []byte) (int, error)

func (*AndFilter) ProtoMessage

func (*AndFilter) ProtoMessage()

func (*AndFilter) Reset

func (m *AndFilter) Reset()

func (*AndFilter) Size

func (m *AndFilter) Size() (n int)

func (*AndFilter) String

func (m *AndFilter) String() string

func (*AndFilter) Unmarshal

func (m *AndFilter) Unmarshal(dAtA []byte) error

type CommonGrpcAccessLogConfig

type CommonGrpcAccessLogConfig struct {
	// The friendly name of the access log to be returned in StreamAccessLogsMessage.Identifier. This
	// allows the access log server to differentiate between different access logs coming from the
	// same Envoy.
	LogName string `protobuf:"bytes,1,opt,name=log_name,json=logName,proto3" json:"log_name,omitempty"`
	// The name of the upstream cluster that hosts the access log service. The cluster must be
	// configured in the cluster manager.
	ClusterName string `protobuf:"bytes,2,opt,name=cluster_name,json=clusterName,proto3" json:"cluster_name,omitempty"`
}

Common configuration for gRPC access logs. [#not-implemented-hide:]

func (*CommonGrpcAccessLogConfig) Descriptor

func (*CommonGrpcAccessLogConfig) Descriptor() ([]byte, []int)

func (*CommonGrpcAccessLogConfig) GetClusterName

func (m *CommonGrpcAccessLogConfig) GetClusterName() string

func (*CommonGrpcAccessLogConfig) GetLogName

func (m *CommonGrpcAccessLogConfig) GetLogName() string

func (*CommonGrpcAccessLogConfig) Marshal

func (m *CommonGrpcAccessLogConfig) Marshal() (dAtA []byte, err error)

func (*CommonGrpcAccessLogConfig) MarshalTo

func (m *CommonGrpcAccessLogConfig) MarshalTo(dAtA []byte) (int, error)

func (*CommonGrpcAccessLogConfig) ProtoMessage

func (*CommonGrpcAccessLogConfig) ProtoMessage()

func (*CommonGrpcAccessLogConfig) Reset

func (m *CommonGrpcAccessLogConfig) Reset()

func (*CommonGrpcAccessLogConfig) Size

func (m *CommonGrpcAccessLogConfig) Size() (n int)

func (*CommonGrpcAccessLogConfig) String

func (m *CommonGrpcAccessLogConfig) String() string

func (*CommonGrpcAccessLogConfig) Unmarshal

func (m *CommonGrpcAccessLogConfig) Unmarshal(dAtA []byte) error

type ComparisonFilter

type ComparisonFilter struct {
	// Comparison operator.
	Op ComparisonFilter_Op `protobuf:"varint,1,opt,name=op,proto3,enum=envoy.api.v2.filter.accesslog.ComparisonFilter_Op" json:"op,omitempty"`
	// Value to compare against.
	Value *envoy_api_v21.RuntimeUInt32 `protobuf:"bytes,2,opt,name=value" json:"value,omitempty"`
}

Filter on an integer comparison.

func (*ComparisonFilter) Descriptor

func (*ComparisonFilter) Descriptor() ([]byte, []int)

func (*ComparisonFilter) GetOp

func (*ComparisonFilter) GetValue

func (*ComparisonFilter) Marshal

func (m *ComparisonFilter) Marshal() (dAtA []byte, err error)

func (*ComparisonFilter) MarshalTo

func (m *ComparisonFilter) MarshalTo(dAtA []byte) (int, error)

func (*ComparisonFilter) ProtoMessage

func (*ComparisonFilter) ProtoMessage()

func (*ComparisonFilter) Reset

func (m *ComparisonFilter) Reset()

func (*ComparisonFilter) Size

func (m *ComparisonFilter) Size() (n int)

func (*ComparisonFilter) String

func (m *ComparisonFilter) String() string

func (*ComparisonFilter) Unmarshal

func (m *ComparisonFilter) Unmarshal(dAtA []byte) error

type ComparisonFilter_Op

type ComparisonFilter_Op int32
const (
	// =
	ComparisonFilter_EQ ComparisonFilter_Op = 0
	// >=
	ComparisonFilter_GE ComparisonFilter_Op = 1
)

func (ComparisonFilter_Op) EnumDescriptor

func (ComparisonFilter_Op) EnumDescriptor() ([]byte, []int)

func (ComparisonFilter_Op) String

func (x ComparisonFilter_Op) String() string

type DurationFilter

type DurationFilter struct {
	// Comparison.
	Comparison *ComparisonFilter `protobuf:"bytes,1,opt,name=comparison" json:"comparison,omitempty"`
}

Filters on total request duration in milliseconds.

func (*DurationFilter) Descriptor

func (*DurationFilter) Descriptor() ([]byte, []int)

func (*DurationFilter) GetComparison

func (m *DurationFilter) GetComparison() *ComparisonFilter

func (*DurationFilter) Marshal

func (m *DurationFilter) Marshal() (dAtA []byte, err error)

func (*DurationFilter) MarshalTo

func (m *DurationFilter) MarshalTo(dAtA []byte) (int, error)

func (*DurationFilter) ProtoMessage

func (*DurationFilter) ProtoMessage()

func (*DurationFilter) Reset

func (m *DurationFilter) Reset()

func (*DurationFilter) Size

func (m *DurationFilter) Size() (n int)

func (*DurationFilter) String

func (m *DurationFilter) String() string

func (*DurationFilter) Unmarshal

func (m *DurationFilter) Unmarshal(dAtA []byte) error

type FileAccessLog

type FileAccessLog struct {
	// A path to a local file to which to write the access log entries.
	Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	// Access log format. Envoy supports :ref:`custom access log formats
	// <config_access_log_format>` as well as a :ref:`default format
	// <config_access_log_default_format>`.
	Format string `protobuf:"bytes,2,opt,name=format,proto3" json:"format,omitempty"`
}

Custom configuration for an AccessLog that writes log entries directly to a file. Configures the built-in *envoy.file_access_log* AccessLog.

func (*FileAccessLog) Descriptor

func (*FileAccessLog) Descriptor() ([]byte, []int)

func (*FileAccessLog) GetFormat

func (m *FileAccessLog) GetFormat() string

func (*FileAccessLog) GetPath

func (m *FileAccessLog) GetPath() string

func (*FileAccessLog) Marshal

func (m *FileAccessLog) Marshal() (dAtA []byte, err error)

func (*FileAccessLog) MarshalTo

func (m *FileAccessLog) MarshalTo(dAtA []byte) (int, error)

func (*FileAccessLog) ProtoMessage

func (*FileAccessLog) ProtoMessage()

func (*FileAccessLog) Reset

func (m *FileAccessLog) Reset()

func (*FileAccessLog) Size

func (m *FileAccessLog) Size() (n int)

func (*FileAccessLog) String

func (m *FileAccessLog) String() string

func (*FileAccessLog) Unmarshal

func (m *FileAccessLog) Unmarshal(dAtA []byte) error

type HTTPAccessLogEntry

type HTTPAccessLogEntry struct {
	// Common properties shared by all Envoy access logs.
	CommonProperties *AccessLogCommon               `protobuf:"bytes,1,opt,name=common_properties,json=commonProperties" json:"common_properties,omitempty"`
	ProtocolVersion  HTTPAccessLogEntry_HTTPVersion `` /* 173-byte string literal not displayed */
	// Description of the incoming HTTP request.
	Request *HTTPRequestProperties `protobuf:"bytes,3,opt,name=request" json:"request,omitempty"`
	// Description of the outgoing HTTP response.
	Response *HTTPResponseProperties `protobuf:"bytes,4,opt,name=response" json:"response,omitempty"`
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*HTTPAccessLogEntry) Descriptor

func (*HTTPAccessLogEntry) Descriptor() ([]byte, []int)

func (*HTTPAccessLogEntry) GetCommonProperties

func (m *HTTPAccessLogEntry) GetCommonProperties() *AccessLogCommon

func (*HTTPAccessLogEntry) GetProtocolVersion

func (m *HTTPAccessLogEntry) GetProtocolVersion() HTTPAccessLogEntry_HTTPVersion

func (*HTTPAccessLogEntry) GetRequest

func (m *HTTPAccessLogEntry) GetRequest() *HTTPRequestProperties

func (*HTTPAccessLogEntry) GetResponse

func (m *HTTPAccessLogEntry) GetResponse() *HTTPResponseProperties

func (*HTTPAccessLogEntry) Marshal

func (m *HTTPAccessLogEntry) Marshal() (dAtA []byte, err error)

func (*HTTPAccessLogEntry) MarshalTo

func (m *HTTPAccessLogEntry) MarshalTo(dAtA []byte) (int, error)

func (*HTTPAccessLogEntry) ProtoMessage

func (*HTTPAccessLogEntry) ProtoMessage()

func (*HTTPAccessLogEntry) Reset

func (m *HTTPAccessLogEntry) Reset()

func (*HTTPAccessLogEntry) Size

func (m *HTTPAccessLogEntry) Size() (n int)

func (*HTTPAccessLogEntry) String

func (m *HTTPAccessLogEntry) String() string

func (*HTTPAccessLogEntry) Unmarshal

func (m *HTTPAccessLogEntry) Unmarshal(dAtA []byte) error

type HTTPAccessLogEntry_HTTPVersion

type HTTPAccessLogEntry_HTTPVersion int32

HTTP version

const (
	HTTPAccessLogEntry_PROTOCOL_UNSPECIFIED HTTPAccessLogEntry_HTTPVersion = 0
	HTTPAccessLogEntry_HTTP10               HTTPAccessLogEntry_HTTPVersion = 1
	HTTPAccessLogEntry_HTTP11               HTTPAccessLogEntry_HTTPVersion = 2
	HTTPAccessLogEntry_HTTP2                HTTPAccessLogEntry_HTTPVersion = 3
)

func (HTTPAccessLogEntry_HTTPVersion) EnumDescriptor

func (HTTPAccessLogEntry_HTTPVersion) EnumDescriptor() ([]byte, []int)

func (HTTPAccessLogEntry_HTTPVersion) String

type HTTPRequestProperties

type HTTPRequestProperties struct {
	// The request method (RFC 7231/2616).
	// [#comment:TODO(htuch): add (validate.rules).enum.defined_only = true once
	// https://github.com/lyft/protoc-gen-validate/issues/42 is resolved.]
	RequestMethod envoy_api_v21.RequestMethod `` /* 133-byte string literal not displayed */
	// The scheme portion of the incoming request URI.
	Scheme string `protobuf:"bytes,2,opt,name=scheme,proto3" json:"scheme,omitempty"`
	// HTTP/2 “:authority“ or HTTP/1.1 “Host“ header value.
	Authority string `protobuf:"bytes,3,opt,name=authority,proto3" json:"authority,omitempty"`
	// The port of the incoming request URI
	// (unused currently, as port is composed onto authority).
	Port *google_protobuf.UInt32Value `protobuf:"bytes,4,opt,name=port" json:"port,omitempty"`
	// The path portion from the incoming request URI.
	Path string `protobuf:"bytes,5,opt,name=path,proto3" json:"path,omitempty"`
	// Value of the “User-Agent“ request header.
	UserAgent string `protobuf:"bytes,6,opt,name=user_agent,json=userAgent,proto3" json:"user_agent,omitempty"`
	// Value of the “Referer“ request header.
	Referer string `protobuf:"bytes,7,opt,name=referer,proto3" json:"referer,omitempty"`
	// Value of the “X-Forwarded-For“ request header.
	ForwardedFor string `protobuf:"bytes,8,opt,name=forwarded_for,json=forwardedFor,proto3" json:"forwarded_for,omitempty"`
	// Value of the “X-Request-Id“ request header
	//
	// This header is used by Envoy to uniquely identify a request.
	// It will be generated for all external requests and internal requests that
	// do not already have a request ID.
	RequestId string `protobuf:"bytes,9,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Value of the “X-Envoy-Original-Path“ request header.
	OriginalPath string `protobuf:"bytes,10,opt,name=original_path,json=originalPath,proto3" json:"original_path,omitempty"`
	// Size of the HTTP request headers in bytes.
	//
	// This value is captured from the OSI layer 7 perspective, i.e. it does not
	// include overhead from framing or encoding at other networking layers.
	RequestHeadersBytes uint64 `protobuf:"varint,11,opt,name=request_headers_bytes,json=requestHeadersBytes,proto3" json:"request_headers_bytes,omitempty"`
	// Size of the HTTP request body in bytes.
	//
	// This value is captured from the OSI layer 7 perspective, i.e. it does not
	// include overhead from framing or encoding at other networking layers.
	RequestBodyBytes uint64 `protobuf:"varint,12,opt,name=request_body_bytes,json=requestBodyBytes,proto3" json:"request_body_bytes,omitempty"`
	// Map of additional headers that have been configured to be logged.
	RequestHeaders map[string]string `` /* 185-byte string literal not displayed */
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*HTTPRequestProperties) Descriptor

func (*HTTPRequestProperties) Descriptor() ([]byte, []int)

func (*HTTPRequestProperties) GetAuthority

func (m *HTTPRequestProperties) GetAuthority() string

func (*HTTPRequestProperties) GetForwardedFor

func (m *HTTPRequestProperties) GetForwardedFor() string

func (*HTTPRequestProperties) GetOriginalPath

func (m *HTTPRequestProperties) GetOriginalPath() string

func (*HTTPRequestProperties) GetPath

func (m *HTTPRequestProperties) GetPath() string

func (*HTTPRequestProperties) GetPort

func (*HTTPRequestProperties) GetReferer

func (m *HTTPRequestProperties) GetReferer() string

func (*HTTPRequestProperties) GetRequestBodyBytes

func (m *HTTPRequestProperties) GetRequestBodyBytes() uint64

func (*HTTPRequestProperties) GetRequestHeaders

func (m *HTTPRequestProperties) GetRequestHeaders() map[string]string

func (*HTTPRequestProperties) GetRequestHeadersBytes

func (m *HTTPRequestProperties) GetRequestHeadersBytes() uint64

func (*HTTPRequestProperties) GetRequestId

func (m *HTTPRequestProperties) GetRequestId() string

func (*HTTPRequestProperties) GetRequestMethod

func (m *HTTPRequestProperties) GetRequestMethod() envoy_api_v21.RequestMethod

func (*HTTPRequestProperties) GetScheme

func (m *HTTPRequestProperties) GetScheme() string

func (*HTTPRequestProperties) GetUserAgent

func (m *HTTPRequestProperties) GetUserAgent() string

func (*HTTPRequestProperties) Marshal

func (m *HTTPRequestProperties) Marshal() (dAtA []byte, err error)

func (*HTTPRequestProperties) MarshalTo

func (m *HTTPRequestProperties) MarshalTo(dAtA []byte) (int, error)

func (*HTTPRequestProperties) ProtoMessage

func (*HTTPRequestProperties) ProtoMessage()

func (*HTTPRequestProperties) Reset

func (m *HTTPRequestProperties) Reset()

func (*HTTPRequestProperties) Size

func (m *HTTPRequestProperties) Size() (n int)

func (*HTTPRequestProperties) String

func (m *HTTPRequestProperties) String() string

func (*HTTPRequestProperties) Unmarshal

func (m *HTTPRequestProperties) Unmarshal(dAtA []byte) error

type HTTPResponseProperties

type HTTPResponseProperties struct {
	// The HTTP response code returned by Envoy.
	ResponseCode *google_protobuf.UInt32Value `protobuf:"bytes,1,opt,name=response_code,json=responseCode" json:"response_code,omitempty"`
	// Size of the HTTP response headers in bytes.
	//
	// This value is captured from the OSI layer 7 perspective, i.e. it does not
	// include overhead from framing or encoding at other networking layers.
	ResponseHeadersBytes uint64 `protobuf:"varint,2,opt,name=response_headers_bytes,json=responseHeadersBytes,proto3" json:"response_headers_bytes,omitempty"`
	// Size of the HTTP response body in bytes.
	//
	// This value is captured from the OSI layer 7 perspective, i.e. it does not
	// include overhead from framing or encoding at other networking layers.
	ResponseBodyBytes uint64 `protobuf:"varint,3,opt,name=response_body_bytes,json=responseBodyBytes,proto3" json:"response_body_bytes,omitempty"`
	// Map of additional headers configured to be logged.
	ResponseHeaders map[string]string `` /* 187-byte string literal not displayed */
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*HTTPResponseProperties) Descriptor

func (*HTTPResponseProperties) Descriptor() ([]byte, []int)

func (*HTTPResponseProperties) GetResponseBodyBytes

func (m *HTTPResponseProperties) GetResponseBodyBytes() uint64

func (*HTTPResponseProperties) GetResponseCode

func (m *HTTPResponseProperties) GetResponseCode() *google_protobuf.UInt32Value

func (*HTTPResponseProperties) GetResponseHeaders

func (m *HTTPResponseProperties) GetResponseHeaders() map[string]string

func (*HTTPResponseProperties) GetResponseHeadersBytes

func (m *HTTPResponseProperties) GetResponseHeadersBytes() uint64

func (*HTTPResponseProperties) Marshal

func (m *HTTPResponseProperties) Marshal() (dAtA []byte, err error)

func (*HTTPResponseProperties) MarshalTo

func (m *HTTPResponseProperties) MarshalTo(dAtA []byte) (int, error)

func (*HTTPResponseProperties) ProtoMessage

func (*HTTPResponseProperties) ProtoMessage()

func (*HTTPResponseProperties) Reset

func (m *HTTPResponseProperties) Reset()

func (*HTTPResponseProperties) Size

func (m *HTTPResponseProperties) Size() (n int)

func (*HTTPResponseProperties) String

func (m *HTTPResponseProperties) String() string

func (*HTTPResponseProperties) Unmarshal

func (m *HTTPResponseProperties) Unmarshal(dAtA []byte) error

type HttpGrpcAccessLogConfig

type HttpGrpcAccessLogConfig struct {
	CommonConfig *CommonGrpcAccessLogConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig" json:"common_config,omitempty"`
	// Additional request headers to log in *HTTPRequestProperties.request_headers*.
	AdditionalRequestHeadersToLog []string `` /* 147-byte string literal not displayed */
	// Additional response headers to log in *HTTPResponseProperties.response_headers*.
	AdditionalResponseHeadersToLog []string `` /* 150-byte string literal not displayed */
}

Configuration for the built-in *envoy.http_grpc_access_log* type. This configuration will populate *StreamAccessLogsMessage.http_logs*. [#not-implemented-hide:] [#comment:TODO(mattklein123): Block type in non-http/router proxy cases?]

func (*HttpGrpcAccessLogConfig) Descriptor

func (*HttpGrpcAccessLogConfig) Descriptor() ([]byte, []int)

func (*HttpGrpcAccessLogConfig) GetAdditionalRequestHeadersToLog

func (m *HttpGrpcAccessLogConfig) GetAdditionalRequestHeadersToLog() []string

func (*HttpGrpcAccessLogConfig) GetAdditionalResponseHeadersToLog

func (m *HttpGrpcAccessLogConfig) GetAdditionalResponseHeadersToLog() []string

func (*HttpGrpcAccessLogConfig) GetCommonConfig

func (m *HttpGrpcAccessLogConfig) GetCommonConfig() *CommonGrpcAccessLogConfig

func (*HttpGrpcAccessLogConfig) Marshal

func (m *HttpGrpcAccessLogConfig) Marshal() (dAtA []byte, err error)

func (*HttpGrpcAccessLogConfig) MarshalTo

func (m *HttpGrpcAccessLogConfig) MarshalTo(dAtA []byte) (int, error)

func (*HttpGrpcAccessLogConfig) ProtoMessage

func (*HttpGrpcAccessLogConfig) ProtoMessage()

func (*HttpGrpcAccessLogConfig) Reset

func (m *HttpGrpcAccessLogConfig) Reset()

func (*HttpGrpcAccessLogConfig) Size

func (m *HttpGrpcAccessLogConfig) Size() (n int)

func (*HttpGrpcAccessLogConfig) String

func (m *HttpGrpcAccessLogConfig) String() string

func (*HttpGrpcAccessLogConfig) Unmarshal

func (m *HttpGrpcAccessLogConfig) Unmarshal(dAtA []byte) error

type NotHealthCheckFilter

type NotHealthCheckFilter struct {
}

Filters for requests that are not health check requests. A health check request is marked by the health check filter.

func (*NotHealthCheckFilter) Descriptor

func (*NotHealthCheckFilter) Descriptor() ([]byte, []int)

func (*NotHealthCheckFilter) Marshal

func (m *NotHealthCheckFilter) Marshal() (dAtA []byte, err error)

func (*NotHealthCheckFilter) MarshalTo

func (m *NotHealthCheckFilter) MarshalTo(dAtA []byte) (int, error)

func (*NotHealthCheckFilter) ProtoMessage

func (*NotHealthCheckFilter) ProtoMessage()

func (*NotHealthCheckFilter) Reset

func (m *NotHealthCheckFilter) Reset()

func (*NotHealthCheckFilter) Size

func (m *NotHealthCheckFilter) Size() (n int)

func (*NotHealthCheckFilter) String

func (m *NotHealthCheckFilter) String() string

func (*NotHealthCheckFilter) Unmarshal

func (m *NotHealthCheckFilter) Unmarshal(dAtA []byte) error

type OrFilter

type OrFilter struct {
	Filters []*AccessLogFilter `protobuf:"bytes,2,rep,name=filters" json:"filters,omitempty"`
}

Performs a logical “or” operation on the result of each individual filter. Filters are evaluated sequentially and if one of them returns true, the filter returns true immediately.

func (*OrFilter) Descriptor

func (*OrFilter) Descriptor() ([]byte, []int)

func (*OrFilter) GetFilters

func (m *OrFilter) GetFilters() []*AccessLogFilter

func (*OrFilter) Marshal

func (m *OrFilter) Marshal() (dAtA []byte, err error)

func (*OrFilter) MarshalTo

func (m *OrFilter) MarshalTo(dAtA []byte) (int, error)

func (*OrFilter) ProtoMessage

func (*OrFilter) ProtoMessage()

func (*OrFilter) Reset

func (m *OrFilter) Reset()

func (*OrFilter) Size

func (m *OrFilter) Size() (n int)

func (*OrFilter) String

func (m *OrFilter) String() string

func (*OrFilter) Unmarshal

func (m *OrFilter) Unmarshal(dAtA []byte) error

type ResponseFlags

type ResponseFlags struct {
	// Indicates local server healthcheck failed.
	FailedLocalHealthcheck bool `` /* 130-byte string literal not displayed */
	// Indicates there was no healthy upstream.
	NoHealthyUpstream bool `protobuf:"varint,2,opt,name=no_healthy_upstream,json=noHealthyUpstream,proto3" json:"no_healthy_upstream,omitempty"`
	// Indicates an there was an upstream request timeout.
	UpstreamRequestTimeout bool `` /* 130-byte string literal not displayed */
	// Indicates local codec level reset was sent on the stream.
	LocalReset bool `protobuf:"varint,4,opt,name=local_reset,json=localReset,proto3" json:"local_reset,omitempty"`
	// Indicates remote codec level reset was received on the stream.
	UpstreamRemoteReset bool `protobuf:"varint,5,opt,name=upstream_remote_reset,json=upstreamRemoteReset,proto3" json:"upstream_remote_reset,omitempty"`
	// Indicates there was a local reset by a connection pool due to an initial connection failure.
	UpstreamConnectionFailure bool `` /* 139-byte string literal not displayed */
	// Indicates the stream was reset locally due to connection termination.
	UpstreamConnectionTermination bool `` /* 151-byte string literal not displayed */
	// Indicates the stream was reset because of a resource overflow.
	UpstreamOverflow bool `protobuf:"varint,8,opt,name=upstream_overflow,json=upstreamOverflow,proto3" json:"upstream_overflow,omitempty"`
	// Indicates no route was found for the request.
	NoRouteFound bool `protobuf:"varint,9,opt,name=no_route_found,json=noRouteFound,proto3" json:"no_route_found,omitempty"`
	// Indicates that the request was delayed before proxying.
	DelayInjected bool `protobuf:"varint,10,opt,name=delay_injected,json=delayInjected,proto3" json:"delay_injected,omitempty"`
	// Indicates that the request was aborted with an injected error code.
	FaultInjected bool `protobuf:"varint,11,opt,name=fault_injected,json=faultInjected,proto3" json:"fault_injected,omitempty"`
	// Indicates that the request was rate-limited locally.
	RateLimited bool `protobuf:"varint,12,opt,name=rate_limited,json=rateLimited,proto3" json:"rate_limited,omitempty"`
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs. Flags indicating occurences during request/response processing.

func (*ResponseFlags) Descriptor

func (*ResponseFlags) Descriptor() ([]byte, []int)

func (*ResponseFlags) GetDelayInjected

func (m *ResponseFlags) GetDelayInjected() bool

func (*ResponseFlags) GetFailedLocalHealthcheck

func (m *ResponseFlags) GetFailedLocalHealthcheck() bool

func (*ResponseFlags) GetFaultInjected

func (m *ResponseFlags) GetFaultInjected() bool

func (*ResponseFlags) GetLocalReset

func (m *ResponseFlags) GetLocalReset() bool

func (*ResponseFlags) GetNoHealthyUpstream

func (m *ResponseFlags) GetNoHealthyUpstream() bool

func (*ResponseFlags) GetNoRouteFound

func (m *ResponseFlags) GetNoRouteFound() bool

func (*ResponseFlags) GetRateLimited

func (m *ResponseFlags) GetRateLimited() bool

func (*ResponseFlags) GetUpstreamConnectionFailure

func (m *ResponseFlags) GetUpstreamConnectionFailure() bool

func (*ResponseFlags) GetUpstreamConnectionTermination

func (m *ResponseFlags) GetUpstreamConnectionTermination() bool

func (*ResponseFlags) GetUpstreamOverflow

func (m *ResponseFlags) GetUpstreamOverflow() bool

func (*ResponseFlags) GetUpstreamRemoteReset

func (m *ResponseFlags) GetUpstreamRemoteReset() bool

func (*ResponseFlags) GetUpstreamRequestTimeout

func (m *ResponseFlags) GetUpstreamRequestTimeout() bool

func (*ResponseFlags) Marshal

func (m *ResponseFlags) Marshal() (dAtA []byte, err error)

func (*ResponseFlags) MarshalTo

func (m *ResponseFlags) MarshalTo(dAtA []byte) (int, error)

func (*ResponseFlags) ProtoMessage

func (*ResponseFlags) ProtoMessage()

func (*ResponseFlags) Reset

func (m *ResponseFlags) Reset()

func (*ResponseFlags) Size

func (m *ResponseFlags) Size() (n int)

func (*ResponseFlags) String

func (m *ResponseFlags) String() string

func (*ResponseFlags) Unmarshal

func (m *ResponseFlags) Unmarshal(dAtA []byte) error

type RuntimeFilter

type RuntimeFilter struct {
	// Runtime key to get the percentage of requests to be sampled. This runtime
	// control is specified in the range 0-100 and defaults to 0.
	RuntimeKey string `protobuf:"bytes,1,opt,name=runtime_key,json=runtimeKey,proto3" json:"runtime_key,omitempty"`
}

Filters for random sampling of requests. Sampling pivots on the header :ref:`x-request-id<config_http_conn_man_headers_x-request-id>` being present. If :ref:`x-request-id<config_http_conn_man_headers_x-request-id>` is present, the filter will consistently sample across multiple hosts based on the runtime key value and the value extracted from :ref:`x-request-id<config_http_conn_man_headers_x-request-id>`. If it is missing, the filter will randomly sample based on the runtime key value.

func (*RuntimeFilter) Descriptor

func (*RuntimeFilter) Descriptor() ([]byte, []int)

func (*RuntimeFilter) GetRuntimeKey

func (m *RuntimeFilter) GetRuntimeKey() string

func (*RuntimeFilter) Marshal

func (m *RuntimeFilter) Marshal() (dAtA []byte, err error)

func (*RuntimeFilter) MarshalTo

func (m *RuntimeFilter) MarshalTo(dAtA []byte) (int, error)

func (*RuntimeFilter) ProtoMessage

func (*RuntimeFilter) ProtoMessage()

func (*RuntimeFilter) Reset

func (m *RuntimeFilter) Reset()

func (*RuntimeFilter) Size

func (m *RuntimeFilter) Size() (n int)

func (*RuntimeFilter) String

func (m *RuntimeFilter) String() string

func (*RuntimeFilter) Unmarshal

func (m *RuntimeFilter) Unmarshal(dAtA []byte) error

type StatusCodeFilter

type StatusCodeFilter struct {
	// Comparison.
	Comparison *ComparisonFilter `protobuf:"bytes,1,opt,name=comparison" json:"comparison,omitempty"`
}

Filters on HTTP response/status code.

func (*StatusCodeFilter) Descriptor

func (*StatusCodeFilter) Descriptor() ([]byte, []int)

func (*StatusCodeFilter) GetComparison

func (m *StatusCodeFilter) GetComparison() *ComparisonFilter

func (*StatusCodeFilter) Marshal

func (m *StatusCodeFilter) Marshal() (dAtA []byte, err error)

func (*StatusCodeFilter) MarshalTo

func (m *StatusCodeFilter) MarshalTo(dAtA []byte) (int, error)

func (*StatusCodeFilter) ProtoMessage

func (*StatusCodeFilter) ProtoMessage()

func (*StatusCodeFilter) Reset

func (m *StatusCodeFilter) Reset()

func (*StatusCodeFilter) Size

func (m *StatusCodeFilter) Size() (n int)

func (*StatusCodeFilter) String

func (m *StatusCodeFilter) String() string

func (*StatusCodeFilter) Unmarshal

func (m *StatusCodeFilter) Unmarshal(dAtA []byte) error

type StreamAccessLogsMessage

type StreamAccessLogsMessage struct {
	// Identifier data that will only be sent in the first message on the stream. This is effectively
	// structured metadata and is a performance optimization.
	Identifier *StreamAccessLogsMessage_Identifier `protobuf:"bytes,1,opt,name=identifier" json:"identifier,omitempty"`
	// Batches of log entries of a single type. Generally speaking, a given stream should only
	// ever incude one type of log entry.
	//
	// Types that are valid to be assigned to LogEntries:
	//	*StreamAccessLogsMessage_HttpLogs
	//	*StreamAccessLogsMessage_TcpLogs
	LogEntries isStreamAccessLogsMessage_LogEntries `protobuf_oneof:"log_entries"`
}

[#proto-status: experimental] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs. Stream message for the StreamAccessLogs API. Envoy will open a stream to the server and stream access logs without ever expecting a response.

func (*StreamAccessLogsMessage) Descriptor

func (*StreamAccessLogsMessage) Descriptor() ([]byte, []int)

func (*StreamAccessLogsMessage) GetHttpLogs

func (*StreamAccessLogsMessage) GetIdentifier

func (*StreamAccessLogsMessage) GetLogEntries

func (m *StreamAccessLogsMessage) GetLogEntries() isStreamAccessLogsMessage_LogEntries

func (*StreamAccessLogsMessage) GetTcpLogs

func (*StreamAccessLogsMessage) Marshal

func (m *StreamAccessLogsMessage) Marshal() (dAtA []byte, err error)

func (*StreamAccessLogsMessage) MarshalTo

func (m *StreamAccessLogsMessage) MarshalTo(dAtA []byte) (int, error)

func (*StreamAccessLogsMessage) ProtoMessage

func (*StreamAccessLogsMessage) ProtoMessage()

func (*StreamAccessLogsMessage) Reset

func (m *StreamAccessLogsMessage) Reset()

func (*StreamAccessLogsMessage) Size

func (m *StreamAccessLogsMessage) Size() (n int)

func (*StreamAccessLogsMessage) String

func (m *StreamAccessLogsMessage) String() string

func (*StreamAccessLogsMessage) Unmarshal

func (m *StreamAccessLogsMessage) Unmarshal(dAtA []byte) error

func (*StreamAccessLogsMessage) XXX_OneofFuncs

func (*StreamAccessLogsMessage) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})

XXX_OneofFuncs is for the internal use of the proto package.

type StreamAccessLogsMessage_HTTPAccessLogEntries

type StreamAccessLogsMessage_HTTPAccessLogEntries struct {
	LogEntry []*HTTPAccessLogEntry `protobuf:"bytes,1,rep,name=log_entry,json=logEntry" json:"log_entry,omitempty"`
}

Wrapper for batches of HTTP access log entries.

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) Descriptor

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) GetLogEntry

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) Marshal

func (m *StreamAccessLogsMessage_HTTPAccessLogEntries) Marshal() (dAtA []byte, err error)

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) MarshalTo

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) ProtoMessage

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) Reset

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) Size

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) String

func (*StreamAccessLogsMessage_HTTPAccessLogEntries) Unmarshal

type StreamAccessLogsMessage_HttpLogs

type StreamAccessLogsMessage_HttpLogs struct {
	HttpLogs *StreamAccessLogsMessage_HTTPAccessLogEntries `protobuf:"bytes,2,opt,name=http_logs,json=httpLogs,oneof"`
}

func (*StreamAccessLogsMessage_HttpLogs) MarshalTo

func (m *StreamAccessLogsMessage_HttpLogs) MarshalTo(dAtA []byte) (int, error)

func (*StreamAccessLogsMessage_HttpLogs) Size

func (m *StreamAccessLogsMessage_HttpLogs) Size() (n int)

type StreamAccessLogsMessage_Identifier

type StreamAccessLogsMessage_Identifier struct {
	// The node sending the access log messages over the stream.
	Node *envoy_api_v21.Node `protobuf:"bytes,1,opt,name=node" json:"node,omitempty"`
	// The friendly name of the log configured in AccessLogServiceConfig.
	LogName string `protobuf:"bytes,2,opt,name=log_name,json=logName,proto3" json:"log_name,omitempty"`
}

func (*StreamAccessLogsMessage_Identifier) Descriptor

func (*StreamAccessLogsMessage_Identifier) Descriptor() ([]byte, []int)

func (*StreamAccessLogsMessage_Identifier) GetLogName

func (*StreamAccessLogsMessage_Identifier) GetNode

func (*StreamAccessLogsMessage_Identifier) Marshal

func (m *StreamAccessLogsMessage_Identifier) Marshal() (dAtA []byte, err error)

func (*StreamAccessLogsMessage_Identifier) MarshalTo

func (m *StreamAccessLogsMessage_Identifier) MarshalTo(dAtA []byte) (int, error)

func (*StreamAccessLogsMessage_Identifier) ProtoMessage

func (*StreamAccessLogsMessage_Identifier) ProtoMessage()

func (*StreamAccessLogsMessage_Identifier) Reset

func (*StreamAccessLogsMessage_Identifier) Size

func (*StreamAccessLogsMessage_Identifier) String

func (*StreamAccessLogsMessage_Identifier) Unmarshal

func (m *StreamAccessLogsMessage_Identifier) Unmarshal(dAtA []byte) error

type StreamAccessLogsMessage_TCPAccessLogEntries

type StreamAccessLogsMessage_TCPAccessLogEntries struct {
	LogEntry []*TCPAccessLogEntry `protobuf:"bytes,1,rep,name=log_entry,json=logEntry" json:"log_entry,omitempty"`
}

Wrapper for batches of TCP access log entries.

func (*StreamAccessLogsMessage_TCPAccessLogEntries) Descriptor

func (*StreamAccessLogsMessage_TCPAccessLogEntries) GetLogEntry

func (*StreamAccessLogsMessage_TCPAccessLogEntries) Marshal

func (m *StreamAccessLogsMessage_TCPAccessLogEntries) Marshal() (dAtA []byte, err error)

func (*StreamAccessLogsMessage_TCPAccessLogEntries) MarshalTo

func (*StreamAccessLogsMessage_TCPAccessLogEntries) ProtoMessage

func (*StreamAccessLogsMessage_TCPAccessLogEntries) Reset

func (*StreamAccessLogsMessage_TCPAccessLogEntries) Size

func (*StreamAccessLogsMessage_TCPAccessLogEntries) String

func (*StreamAccessLogsMessage_TCPAccessLogEntries) Unmarshal

type StreamAccessLogsMessage_TcpLogs

type StreamAccessLogsMessage_TcpLogs struct {
	TcpLogs *StreamAccessLogsMessage_TCPAccessLogEntries `protobuf:"bytes,3,opt,name=tcp_logs,json=tcpLogs,oneof"`
}

func (*StreamAccessLogsMessage_TcpLogs) MarshalTo

func (m *StreamAccessLogsMessage_TcpLogs) MarshalTo(dAtA []byte) (int, error)

func (*StreamAccessLogsMessage_TcpLogs) Size

func (m *StreamAccessLogsMessage_TcpLogs) Size() (n int)

type StreamAccessLogsResponse

type StreamAccessLogsResponse struct {
}

Empty response for the StreamAccessLogs API. Will never be sent. See below. [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*StreamAccessLogsResponse) Descriptor

func (*StreamAccessLogsResponse) Descriptor() ([]byte, []int)

func (*StreamAccessLogsResponse) Marshal

func (m *StreamAccessLogsResponse) Marshal() (dAtA []byte, err error)

func (*StreamAccessLogsResponse) MarshalTo

func (m *StreamAccessLogsResponse) MarshalTo(dAtA []byte) (int, error)

func (*StreamAccessLogsResponse) ProtoMessage

func (*StreamAccessLogsResponse) ProtoMessage()

func (*StreamAccessLogsResponse) Reset

func (m *StreamAccessLogsResponse) Reset()

func (*StreamAccessLogsResponse) Size

func (m *StreamAccessLogsResponse) Size() (n int)

func (*StreamAccessLogsResponse) String

func (m *StreamAccessLogsResponse) String() string

func (*StreamAccessLogsResponse) Unmarshal

func (m *StreamAccessLogsResponse) Unmarshal(dAtA []byte) error

type TCPAccessLogEntry

type TCPAccessLogEntry struct {
	// Common properties shared by all Envoy access logs.
	CommonProperties *AccessLogCommon `protobuf:"bytes,1,opt,name=common_properties,json=commonProperties" json:"common_properties,omitempty"`
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs.

func (*TCPAccessLogEntry) Descriptor

func (*TCPAccessLogEntry) Descriptor() ([]byte, []int)

func (*TCPAccessLogEntry) GetCommonProperties

func (m *TCPAccessLogEntry) GetCommonProperties() *AccessLogCommon

func (*TCPAccessLogEntry) Marshal

func (m *TCPAccessLogEntry) Marshal() (dAtA []byte, err error)

func (*TCPAccessLogEntry) MarshalTo

func (m *TCPAccessLogEntry) MarshalTo(dAtA []byte) (int, error)

func (*TCPAccessLogEntry) ProtoMessage

func (*TCPAccessLogEntry) ProtoMessage()

func (*TCPAccessLogEntry) Reset

func (m *TCPAccessLogEntry) Reset()

func (*TCPAccessLogEntry) Size

func (m *TCPAccessLogEntry) Size() (n int)

func (*TCPAccessLogEntry) String

func (m *TCPAccessLogEntry) String() string

func (*TCPAccessLogEntry) Unmarshal

func (m *TCPAccessLogEntry) Unmarshal(dAtA []byte) error

type TLSProperties

type TLSProperties struct {
	// Version of TLS that was negotiated.
	TlsVersion TLSProperties_TLSVersion `` /* 152-byte string literal not displayed */
	// TLS cipher suite negotiated during handshake. The value is a
	// four-digit hex code defined by the IANA TLS Cipher Suite Registry
	// (e.g. “009C“ for “TLS_RSA_WITH_AES_128_GCM_SHA256“).
	//
	// Here it is expressed as an integer.
	TlsCipherSuite *google_protobuf.UInt32Value `protobuf:"bytes,2,opt,name=tls_cipher_suite,json=tlsCipherSuite" json:"tls_cipher_suite,omitempty"`
	// SNI hostname from handshake.
	TlsSniHostname string `protobuf:"bytes,3,opt,name=tls_sni_hostname,json=tlsSniHostname,proto3" json:"tls_sni_hostname,omitempty"`
}

[#proto-status: draft] [#not-implemented-hide:] Not configuration. TBD how to doc proto APIs. Properties of a negotiated TLS connection.

func (*TLSProperties) Descriptor

func (*TLSProperties) Descriptor() ([]byte, []int)

func (*TLSProperties) GetTlsCipherSuite

func (m *TLSProperties) GetTlsCipherSuite() *google_protobuf.UInt32Value

func (*TLSProperties) GetTlsSniHostname

func (m *TLSProperties) GetTlsSniHostname() string

func (*TLSProperties) GetTlsVersion

func (m *TLSProperties) GetTlsVersion() TLSProperties_TLSVersion

func (*TLSProperties) Marshal

func (m *TLSProperties) Marshal() (dAtA []byte, err error)

func (*TLSProperties) MarshalTo

func (m *TLSProperties) MarshalTo(dAtA []byte) (int, error)

func (*TLSProperties) ProtoMessage

func (*TLSProperties) ProtoMessage()

func (*TLSProperties) Reset

func (m *TLSProperties) Reset()

func (*TLSProperties) Size

func (m *TLSProperties) Size() (n int)

func (*TLSProperties) String

func (m *TLSProperties) String() string

func (*TLSProperties) Unmarshal

func (m *TLSProperties) Unmarshal(dAtA []byte) error

type TLSProperties_TLSVersion

type TLSProperties_TLSVersion int32
const (
	TLSProperties_VERSION_UNSPECIFIED TLSProperties_TLSVersion = 0
	TLSProperties_TLSv1               TLSProperties_TLSVersion = 1
	TLSProperties_TLSv1_1             TLSProperties_TLSVersion = 2
	TLSProperties_TLSv1_2             TLSProperties_TLSVersion = 3
	TLSProperties_TLSv1_3             TLSProperties_TLSVersion = 4
)

func (TLSProperties_TLSVersion) EnumDescriptor

func (TLSProperties_TLSVersion) EnumDescriptor() ([]byte, []int)

func (TLSProperties_TLSVersion) String

func (x TLSProperties_TLSVersion) String() string

type TcpGrpcAccessLogConfig

type TcpGrpcAccessLogConfig struct {
	CommonConfig *CommonGrpcAccessLogConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig" json:"common_config,omitempty"`
}

Configuration for the built-in *envoy.tcp_grpc_access_log* type. This configuration will populate *StreamAccessLogsMessage.tcp_logs*. [#not-implemented-hide:] [#comment:TODO(mattklein123): Block type in non-tcp proxy cases?]

func (*TcpGrpcAccessLogConfig) Descriptor

func (*TcpGrpcAccessLogConfig) Descriptor() ([]byte, []int)

func (*TcpGrpcAccessLogConfig) GetCommonConfig

func (m *TcpGrpcAccessLogConfig) GetCommonConfig() *CommonGrpcAccessLogConfig

func (*TcpGrpcAccessLogConfig) Marshal

func (m *TcpGrpcAccessLogConfig) Marshal() (dAtA []byte, err error)

func (*TcpGrpcAccessLogConfig) MarshalTo

func (m *TcpGrpcAccessLogConfig) MarshalTo(dAtA []byte) (int, error)

func (*TcpGrpcAccessLogConfig) ProtoMessage

func (*TcpGrpcAccessLogConfig) ProtoMessage()

func (*TcpGrpcAccessLogConfig) Reset

func (m *TcpGrpcAccessLogConfig) Reset()

func (*TcpGrpcAccessLogConfig) Size

func (m *TcpGrpcAccessLogConfig) Size() (n int)

func (*TcpGrpcAccessLogConfig) String

func (m *TcpGrpcAccessLogConfig) String() string

func (*TcpGrpcAccessLogConfig) Unmarshal

func (m *TcpGrpcAccessLogConfig) Unmarshal(dAtA []byte) error

type TraceableFilter

type TraceableFilter struct {
}

Filters for requests that are traceable. See the tracing overview for more information on how a request becomes traceable.

func (*TraceableFilter) Descriptor

func (*TraceableFilter) Descriptor() ([]byte, []int)

func (*TraceableFilter) Marshal

func (m *TraceableFilter) Marshal() (dAtA []byte, err error)

func (*TraceableFilter) MarshalTo

func (m *TraceableFilter) MarshalTo(dAtA []byte) (int, error)

func (*TraceableFilter) ProtoMessage

func (*TraceableFilter) ProtoMessage()

func (*TraceableFilter) Reset

func (m *TraceableFilter) Reset()

func (*TraceableFilter) Size

func (m *TraceableFilter) Size() (n int)

func (*TraceableFilter) String

func (m *TraceableFilter) String() string

func (*TraceableFilter) Unmarshal

func (m *TraceableFilter) Unmarshal(dAtA []byte) error

Jump to