network

package
v0.0.0-...-84cf697 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2018 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package network is a generated protocol buffer package.

It is generated from these files:

api/filter/network/client_ssl_auth.proto
api/filter/network/http_connection_manager.proto
api/filter/network/mongo_proxy.proto
api/filter/network/rate_limit.proto
api/filter/network/redis_proxy.proto
api/filter/network/tcp_proxy.proto

It has these top-level messages:

ClientSSLAuth
HttpConnectionManager
Rds
HttpFilter
MongoProxy
RateLimit
RedisProxy
TcpProxy

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidLengthClientSslAuth = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowClientSslAuth   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthHttpConnectionManager = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowHttpConnectionManager   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthMongoProxy = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowMongoProxy   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthRateLimit = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowRateLimit   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthRedisProxy = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowRedisProxy   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthTcpProxy = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowTcpProxy   = fmt.Errorf("proto: integer overflow")
)
var HttpConnectionManager_CodecType_name = map[int32]string{
	0: "AUTO",
	1: "HTTP1",
	2: "HTTP2",
}
var HttpConnectionManager_CodecType_value = map[string]int32{
	"AUTO":  0,
	"HTTP1": 1,
	"HTTP2": 2,
}
var HttpConnectionManager_ForwardClientCertDetails_name = map[int32]string{
	0: "SANITIZE",
	1: "FORWARD_ONLY",
	2: "APPEND_FORWARD",
	3: "SANITIZE_SET",
	4: "ALWAYS_FORWARD_ONLY",
}
var HttpConnectionManager_ForwardClientCertDetails_value = map[string]int32{
	"SANITIZE":            0,
	"FORWARD_ONLY":        1,
	"APPEND_FORWARD":      2,
	"SANITIZE_SET":        3,
	"ALWAYS_FORWARD_ONLY": 4,
}
var HttpConnectionManager_Tracing_OperationName_name = map[int32]string{
	0: "INGRESS",
	1: "EGRESS",
}
var HttpConnectionManager_Tracing_OperationName_value = map[string]int32{
	"INGRESS": 0,
	"EGRESS":  1,
}

Functions

This section is empty.

Types

type ClientSSLAuth

type ClientSSLAuth struct {
	// The :ref:`cluster manager <arch_overview_cluster_manager>` cluster that runs
	// the authentication service. The filter will connect to the service every 60s to fetch the list
	// of principals. The service must support the expected :ref:`REST API
	// <config_network_filters_client_ssl_auth_rest_api>`.
	AuthApiCluster string `protobuf:"bytes,1,opt,name=auth_api_cluster,json=authApiCluster,proto3" json:"auth_api_cluster,omitempty"`
	// The prefix to use when emitting :ref:`statistics
	// <config_network_filters_client_ssl_auth_stats>`.
	StatPrefix string `protobuf:"bytes,2,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Time in milliseconds between principal refreshes from the
	// authentication service. Default is 60000 (60s). The actual fetch time
	// will be this value plus a random jittered value between
	// 0-refresh_delay_ms milliseconds.
	RefreshDelay *google_protobuf2.Duration `protobuf:"bytes,3,opt,name=refresh_delay,json=refreshDelay" json:"refresh_delay,omitempty"`
	// An optional list of IP address and subnet masks that should be white
	// listed for access by the filter. If no list is provided, there is no
	// IP white list.
	IpWhiteList []*envoy_api_v2.CidrRange `protobuf:"bytes,4,rep,name=ip_white_list,json=ipWhiteList" json:"ip_white_list,omitempty"`
}

func (*ClientSSLAuth) Descriptor

func (*ClientSSLAuth) Descriptor() ([]byte, []int)

func (*ClientSSLAuth) GetAuthApiCluster

func (m *ClientSSLAuth) GetAuthApiCluster() string

func (*ClientSSLAuth) GetIpWhiteList

func (m *ClientSSLAuth) GetIpWhiteList() []*envoy_api_v2.CidrRange

func (*ClientSSLAuth) GetRefreshDelay

func (m *ClientSSLAuth) GetRefreshDelay() *google_protobuf2.Duration

func (*ClientSSLAuth) GetStatPrefix

func (m *ClientSSLAuth) GetStatPrefix() string

func (*ClientSSLAuth) Marshal

func (m *ClientSSLAuth) Marshal() (dAtA []byte, err error)

func (*ClientSSLAuth) MarshalTo

func (m *ClientSSLAuth) MarshalTo(dAtA []byte) (int, error)

func (*ClientSSLAuth) ProtoMessage

func (*ClientSSLAuth) ProtoMessage()

func (*ClientSSLAuth) Reset

func (m *ClientSSLAuth) Reset()

func (*ClientSSLAuth) Size

func (m *ClientSSLAuth) Size() (n int)

func (*ClientSSLAuth) String

func (m *ClientSSLAuth) String() string

func (*ClientSSLAuth) Unmarshal

func (m *ClientSSLAuth) Unmarshal(dAtA []byte) error

type HttpConnectionManager

type HttpConnectionManager struct {
	// Supplies the type of codec that the connection manager should use.
	CodecType HttpConnectionManager_CodecType `` /* 154-byte string literal not displayed */
	// The human readable prefix to use when emitting statistics for the
	// connection manager. See the :ref:`statistics documentation <config_http_conn_man_stats>` for
	// more information.
	StatPrefix string `protobuf:"bytes,2,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Types that are valid to be assigned to RouteSpecifier:
	//	*HttpConnectionManager_Rds
	//	*HttpConnectionManager_RouteConfig
	RouteSpecifier isHttpConnectionManager_RouteSpecifier `protobuf_oneof:"route_specifier"`
	// A list of individual HTTP filters that make up the filter chain for
	// requests made to the connection manager. Order matters as the filters are
	// processed sequentially as request events happen.
	HttpFilters []*HttpFilter `protobuf:"bytes,5,rep,name=http_filters,json=httpFilters" json:"http_filters,omitempty"`
	// Whether the connection manager manipulates the :ref:`config_http_conn_man_headers_user-agent`
	// and :ref:`config_http_conn_man_headers_downstream-service-cluster` headers. See the linked
	// documentation for more information. Defaults to false.
	AddUserAgent *google_protobuf.BoolValue `protobuf:"bytes,6,opt,name=add_user_agent,json=addUserAgent" json:"add_user_agent,omitempty"`
	// Presence of the object defines whether the connection manager
	// emits :ref:`tracing <arch_overview_tracing>` data to the :ref:`configured tracing provider
	// <envoy_api_msg_Tracing>`.
	Tracing *HttpConnectionManager_Tracing `protobuf:"bytes,7,opt,name=tracing" json:"tracing,omitempty"`
	// Additional HTTP/1 settings that are passed to the HTTP/1 codec.
	HttpProtocolOptions *envoy_api_v22.Http1ProtocolOptions `protobuf:"bytes,8,opt,name=http_protocol_options,json=httpProtocolOptions" json:"http_protocol_options,omitempty"`
	// Additional HTTP/2 settings that are passed directly to the HTTP/2 codec.
	Http2ProtocolOptions *envoy_api_v22.Http2ProtocolOptions `protobuf:"bytes,9,opt,name=http2_protocol_options,json=http2ProtocolOptions" json:"http2_protocol_options,omitempty"`
	// An optional override that the connection manager will write to the server
	// header in responses. If not set, the default is *envoy*.
	ServerName string `protobuf:"bytes,10,opt,name=server_name,json=serverName,proto3" json:"server_name,omitempty"`
	// The idle timeout for connections managed by the connection manager. The
	// idle timeout is defined as the period in which there are no active
	// requests. If not set, there is no idle timeout. When the idle timeout is
	// reached the connection will be closed. If the connection is an HTTP/2
	// connection a drain sequence will occur prior to closing the connection. See
	// :ref:`drain_timeout <envoy_api_field_filter.network.HttpConnectionManager.drain_timeout>`.
	IdleTimeout *time.Duration `protobuf:"bytes,11,opt,name=idle_timeout,json=idleTimeout,stdduration" json:"idle_timeout,omitempty"`
	// The time that Envoy will wait between sending an HTTP/2 “shutdown
	// notification” (GOAWAY frame with max stream ID) and a final GOAWAY frame.
	// This is used so that Envoy provides a grace period for new streams that
	// race with the final GOAWAY frame. During this grace period, Envoy will
	// continue to accept new streams. After the grace period, a final GOAWAY
	// frame is sent and Envoy will start refusing new streams. Draining occurs
	// both when a connection hits the idle timeout or during general server
	// draining. The default grace period is 5000 milliseconds (5 seconds) if this
	// option is not specified.
	DrainTimeout *time.Duration `protobuf:"bytes,12,opt,name=drain_timeout,json=drainTimeout,stdduration" json:"drain_timeout,omitempty"`
	// Configuration for :ref:`HTTP access logs <arch_overview_access_logs>`
	// emitted by the connection manager.
	AccessLog []*envoy_api_v2_filter_accesslog.AccessLog `protobuf:"bytes,13,rep,name=access_log,json=accessLog" json:"access_log,omitempty"`
	// If set to true, the connection manager will use the real remote address
	// of the client connection when determining internal versus external origin and manipulating
	// various headers. If set to false or absent, the connection manager will use the
	// :ref:`config_http_conn_man_headers_x-forwarded-for` HTTP header. See the documentation for
	// :ref:`config_http_conn_man_headers_x-forwarded-for`,
	// :ref:`config_http_conn_man_headers_x-envoy-internal`, and
	// :ref:`config_http_conn_man_headers_x-envoy-external-address` for more information.
	UseRemoteAddress *google_protobuf.BoolValue `protobuf:"bytes,14,opt,name=use_remote_address,json=useRemoteAddress" json:"use_remote_address,omitempty"`
	// Whether the connection manager will generate the :ref:`x-request-id
	// <config_http_conn_man_headers_x-request-id>` header if it does not exist. This defaults to
	// true. Generating a random UUID4 is expensive so in high throughput scenarios where this feature
	// is not desired it can be disabled.
	GenerateRequestId *google_protobuf.BoolValue `protobuf:"bytes,15,opt,name=generate_request_id,json=generateRequestId" json:"generate_request_id,omitempty"`
	// How to handle the :ref:`config_http_conn_man_headers_x-forwarded-client-cert` (XFCC) HTTP
	// header.
	ForwardClientCertDetails HttpConnectionManager_ForwardClientCertDetails `` /* 219-byte string literal not displayed */
	// This field is valid only when :ref:`forward_client_cert_details
	// <envoy_api_field_filter.network.HttpConnectionManager.forward_client_cert_details>` is
	// APPEND_FORWARD or SANITIZE_SET and the client connection is mTLS. It specifies the fields in
	// the client certificate to be forwarded. Note that in the
	// :ref:`config_http_conn_man_headers_x-forwarded-client-cert` header, *Hash* is always set, and
	// *By* is always set when the client certificate presents the SAN value.
	SetCurrentClientCertDetails *HttpConnectionManager_SetCurrentClientCertDetails `` /* 142-byte string literal not displayed */
}

func (*HttpConnectionManager) Descriptor

func (*HttpConnectionManager) Descriptor() ([]byte, []int)

func (*HttpConnectionManager) GetAccessLog

func (*HttpConnectionManager) GetAddUserAgent

func (m *HttpConnectionManager) GetAddUserAgent() *google_protobuf.BoolValue

func (*HttpConnectionManager) GetCodecType

func (*HttpConnectionManager) GetDrainTimeout

func (m *HttpConnectionManager) GetDrainTimeout() *time.Duration

func (*HttpConnectionManager) GetForwardClientCertDetails

func (*HttpConnectionManager) GetGenerateRequestId

func (m *HttpConnectionManager) GetGenerateRequestId() *google_protobuf.BoolValue

func (*HttpConnectionManager) GetHttp2ProtocolOptions

func (m *HttpConnectionManager) GetHttp2ProtocolOptions() *envoy_api_v22.Http2ProtocolOptions

func (*HttpConnectionManager) GetHttpFilters

func (m *HttpConnectionManager) GetHttpFilters() []*HttpFilter

func (*HttpConnectionManager) GetHttpProtocolOptions

func (m *HttpConnectionManager) GetHttpProtocolOptions() *envoy_api_v22.Http1ProtocolOptions

func (*HttpConnectionManager) GetIdleTimeout

func (m *HttpConnectionManager) GetIdleTimeout() *time.Duration

func (*HttpConnectionManager) GetRds

func (m *HttpConnectionManager) GetRds() *Rds

func (*HttpConnectionManager) GetRouteConfig

func (*HttpConnectionManager) GetRouteSpecifier

func (m *HttpConnectionManager) GetRouteSpecifier() isHttpConnectionManager_RouteSpecifier

func (*HttpConnectionManager) GetServerName

func (m *HttpConnectionManager) GetServerName() string

func (*HttpConnectionManager) GetSetCurrentClientCertDetails

func (m *HttpConnectionManager) GetSetCurrentClientCertDetails() *HttpConnectionManager_SetCurrentClientCertDetails

func (*HttpConnectionManager) GetStatPrefix

func (m *HttpConnectionManager) GetStatPrefix() string

func (*HttpConnectionManager) GetTracing

func (*HttpConnectionManager) GetUseRemoteAddress

func (m *HttpConnectionManager) GetUseRemoteAddress() *google_protobuf.BoolValue

func (*HttpConnectionManager) Marshal

func (m *HttpConnectionManager) Marshal() (dAtA []byte, err error)

func (*HttpConnectionManager) MarshalTo

func (m *HttpConnectionManager) MarshalTo(dAtA []byte) (int, error)

func (*HttpConnectionManager) ProtoMessage

func (*HttpConnectionManager) ProtoMessage()

func (*HttpConnectionManager) Reset

func (m *HttpConnectionManager) Reset()

func (*HttpConnectionManager) Size

func (m *HttpConnectionManager) Size() (n int)

func (*HttpConnectionManager) String

func (m *HttpConnectionManager) String() string

func (*HttpConnectionManager) Unmarshal

func (m *HttpConnectionManager) Unmarshal(dAtA []byte) error

func (*HttpConnectionManager) XXX_OneofFuncs

func (*HttpConnectionManager) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})

XXX_OneofFuncs is for the internal use of the proto package.

type HttpConnectionManager_CodecType

type HttpConnectionManager_CodecType int32
const (
	// For every new connection, the connection manager will determine which
	// codec to use. This mode supports both ALPN for TLS listeners as well as
	// protocol inference for plaintext listeners. If ALPN data is available, it
	// is preferred, otherwise protocol inference is used. In almost all cases,
	// this is the right option to choose for this setting.
	HttpConnectionManager_AUTO HttpConnectionManager_CodecType = 0
	// The connection manager will assume that the client is speaking HTTP/1.1.
	HttpConnectionManager_HTTP1 HttpConnectionManager_CodecType = 1
	// The connection manager will assume that the client is speaking HTTP/2
	// (Envoy does not require HTTP/2 to take place over TLS or to use ALPN.
	// Prior knowledge is allowed).
	HttpConnectionManager_HTTP2 HttpConnectionManager_CodecType = 2
)

func (HttpConnectionManager_CodecType) EnumDescriptor

func (HttpConnectionManager_CodecType) EnumDescriptor() ([]byte, []int)

func (HttpConnectionManager_CodecType) String

type HttpConnectionManager_ForwardClientCertDetails

type HttpConnectionManager_ForwardClientCertDetails int32

How to handle the :ref:`config_http_conn_man_headers_x-forwarded-client-cert` (XFCC) HTTP header.

const (
	// Do not send the XFCC header to the next hop. This is the default value.
	HttpConnectionManager_SANITIZE HttpConnectionManager_ForwardClientCertDetails = 0
	// When the client connection is mTLS (Mutual TLS), forward the XFCC header
	// in the request.
	HttpConnectionManager_FORWARD_ONLY HttpConnectionManager_ForwardClientCertDetails = 1
	// When the client connection is mTLS, append the client certificate
	// information to the request’s XFCC header and forward it.
	HttpConnectionManager_APPEND_FORWARD HttpConnectionManager_ForwardClientCertDetails = 2
	// When the client connection is mTLS, reset the XFCC header with the client
	// certificate information and send it to the next hop.
	HttpConnectionManager_SANITIZE_SET HttpConnectionManager_ForwardClientCertDetails = 3
	// Always forward the XFCC header in the request, regardless of whether the
	// client connection is mTLS.
	HttpConnectionManager_ALWAYS_FORWARD_ONLY HttpConnectionManager_ForwardClientCertDetails = 4
)

func (HttpConnectionManager_ForwardClientCertDetails) EnumDescriptor

func (HttpConnectionManager_ForwardClientCertDetails) String

type HttpConnectionManager_Rds

type HttpConnectionManager_Rds struct {
	Rds *Rds `protobuf:"bytes,3,opt,name=rds,oneof"`
}

func (*HttpConnectionManager_Rds) MarshalTo

func (m *HttpConnectionManager_Rds) MarshalTo(dAtA []byte) (int, error)

func (*HttpConnectionManager_Rds) Size

func (m *HttpConnectionManager_Rds) Size() (n int)

type HttpConnectionManager_RouteConfig

type HttpConnectionManager_RouteConfig struct {
	RouteConfig *envoy_api_v25.RouteConfiguration `protobuf:"bytes,4,opt,name=route_config,json=routeConfig,oneof"`
}

func (*HttpConnectionManager_RouteConfig) MarshalTo

func (m *HttpConnectionManager_RouteConfig) MarshalTo(dAtA []byte) (int, error)

func (*HttpConnectionManager_RouteConfig) Size

func (m *HttpConnectionManager_RouteConfig) Size() (n int)

type HttpConnectionManager_SetCurrentClientCertDetails

type HttpConnectionManager_SetCurrentClientCertDetails struct {
	// Whether to forward the subject of the client cert. Defaults to false.
	Subject *google_protobuf.BoolValue `protobuf:"bytes,1,opt,name=subject" json:"subject,omitempty"`
	// Whether to forward the SAN of the client cert. Defaults to false.
	San *google_protobuf.BoolValue `protobuf:"bytes,2,opt,name=san" json:"san,omitempty"`
}

func (*HttpConnectionManager_SetCurrentClientCertDetails) Descriptor

func (*HttpConnectionManager_SetCurrentClientCertDetails) GetSan

func (*HttpConnectionManager_SetCurrentClientCertDetails) GetSubject

func (*HttpConnectionManager_SetCurrentClientCertDetails) Marshal

func (*HttpConnectionManager_SetCurrentClientCertDetails) MarshalTo

func (*HttpConnectionManager_SetCurrentClientCertDetails) ProtoMessage

func (*HttpConnectionManager_SetCurrentClientCertDetails) Reset

func (*HttpConnectionManager_SetCurrentClientCertDetails) Size

func (*HttpConnectionManager_SetCurrentClientCertDetails) String

func (*HttpConnectionManager_SetCurrentClientCertDetails) Unmarshal

type HttpConnectionManager_Tracing

type HttpConnectionManager_Tracing struct {
	// The span name will be derived from this field.
	OperationName HttpConnectionManager_Tracing_OperationName `` /* 178-byte string literal not displayed */
	// A list of header names used to create tags for the active span. The header name is used to
	// populate the tag name, and the header value is used to populate the tag value. The tag is
	// created if the specified header name is present in the request's headers.
	RequestHeadersForTags []string `protobuf:"bytes,2,rep,name=request_headers_for_tags,json=requestHeadersForTags" json:"request_headers_for_tags,omitempty"`
}

func (*HttpConnectionManager_Tracing) Descriptor

func (*HttpConnectionManager_Tracing) Descriptor() ([]byte, []int)

func (*HttpConnectionManager_Tracing) GetOperationName

func (*HttpConnectionManager_Tracing) GetRequestHeadersForTags

func (m *HttpConnectionManager_Tracing) GetRequestHeadersForTags() []string

func (*HttpConnectionManager_Tracing) Marshal

func (m *HttpConnectionManager_Tracing) Marshal() (dAtA []byte, err error)

func (*HttpConnectionManager_Tracing) MarshalTo

func (m *HttpConnectionManager_Tracing) MarshalTo(dAtA []byte) (int, error)

func (*HttpConnectionManager_Tracing) ProtoMessage

func (*HttpConnectionManager_Tracing) ProtoMessage()

func (*HttpConnectionManager_Tracing) Reset

func (m *HttpConnectionManager_Tracing) Reset()

func (*HttpConnectionManager_Tracing) Size

func (m *HttpConnectionManager_Tracing) Size() (n int)

func (*HttpConnectionManager_Tracing) String

func (*HttpConnectionManager_Tracing) Unmarshal

func (m *HttpConnectionManager_Tracing) Unmarshal(dAtA []byte) error

type HttpConnectionManager_Tracing_OperationName

type HttpConnectionManager_Tracing_OperationName int32
const (
	// The HTTP listener is used for ingress/incoming requests.
	HttpConnectionManager_Tracing_INGRESS HttpConnectionManager_Tracing_OperationName = 0
	// The HTTP listener is used for egress/outgoing requests.
	HttpConnectionManager_Tracing_EGRESS HttpConnectionManager_Tracing_OperationName = 1
)

func (HttpConnectionManager_Tracing_OperationName) EnumDescriptor

func (HttpConnectionManager_Tracing_OperationName) EnumDescriptor() ([]byte, []int)

func (HttpConnectionManager_Tracing_OperationName) String

type HttpFilter

type HttpFilter struct {
	// The name of the filter to instantiate. The name must match a supported
	// filter. The built-in filters are:
	//
	// [#comment:TODO(mattklein123): Auto generate the following list]
	// * :ref:`envoy.buffer <config_http_filters_buffer>`
	// * :ref:`envoy.cors <config_http_filters_cors>`
	// * :ref:`envoy.fault <config_http_filters_fault_injection>`
	// * :ref:`envoy.http_dynamo_filter <config_http_filters_dynamo>`
	// * :ref:`envoy.grpc_http1_bridge <config_http_filters_grpc_bridge>`
	// * :ref:`envoy.grpc_json_transcoder <config_http_filters_grpc_json_transcoder>`
	// * :ref:`envoy.grpc_web <config_http_filters_grpc_web>`
	// * :ref:`envoy.health_check <config_http_filters_health_check>`
	// * :ref:`envoy.lua <config_http_filters_lua>`
	// * :ref:`envoy.rate_limit <config_http_filters_rate_limit>`
	// * :ref:`envoy.router <config_http_filters_router>`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Filter specific configuration which depends on the filter being
	// instantiated. See the supported filters for further documentation.
	Config *google_protobuf4.Struct `protobuf:"bytes,2,opt,name=config" json:"config,omitempty"`
	// [#not-implemented-hide:]
	// This is hidden as type has been deprecated and is no longer required.
	DeprecatedV1 *HttpFilter_DeprecatedV1 `protobuf:"bytes,3,opt,name=deprecated_v1,json=deprecatedV1" json:"deprecated_v1,omitempty"`
}

func (*HttpFilter) Descriptor

func (*HttpFilter) Descriptor() ([]byte, []int)

func (*HttpFilter) GetConfig

func (m *HttpFilter) GetConfig() *google_protobuf4.Struct

func (*HttpFilter) GetDeprecatedV1

func (m *HttpFilter) GetDeprecatedV1() *HttpFilter_DeprecatedV1

func (*HttpFilter) GetName

func (m *HttpFilter) GetName() string

func (*HttpFilter) Marshal

func (m *HttpFilter) Marshal() (dAtA []byte, err error)

func (*HttpFilter) MarshalTo

func (m *HttpFilter) MarshalTo(dAtA []byte) (int, error)

func (*HttpFilter) ProtoMessage

func (*HttpFilter) ProtoMessage()

func (*HttpFilter) Reset

func (m *HttpFilter) Reset()

func (*HttpFilter) Size

func (m *HttpFilter) Size() (n int)

func (*HttpFilter) String

func (m *HttpFilter) String() string

func (*HttpFilter) Unmarshal

func (m *HttpFilter) Unmarshal(dAtA []byte) error

type HttpFilter_DeprecatedV1

type HttpFilter_DeprecatedV1 struct {
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
}

[#not-implemented-hide:] This is hidden as type has been deprecated and is no longer required.

func (*HttpFilter_DeprecatedV1) Descriptor

func (*HttpFilter_DeprecatedV1) Descriptor() ([]byte, []int)

func (*HttpFilter_DeprecatedV1) GetType

func (m *HttpFilter_DeprecatedV1) GetType() string

func (*HttpFilter_DeprecatedV1) Marshal

func (m *HttpFilter_DeprecatedV1) Marshal() (dAtA []byte, err error)

func (*HttpFilter_DeprecatedV1) MarshalTo

func (m *HttpFilter_DeprecatedV1) MarshalTo(dAtA []byte) (int, error)

func (*HttpFilter_DeprecatedV1) ProtoMessage

func (*HttpFilter_DeprecatedV1) ProtoMessage()

func (*HttpFilter_DeprecatedV1) Reset

func (m *HttpFilter_DeprecatedV1) Reset()

func (*HttpFilter_DeprecatedV1) Size

func (m *HttpFilter_DeprecatedV1) Size() (n int)

func (*HttpFilter_DeprecatedV1) String

func (m *HttpFilter_DeprecatedV1) String() string

func (*HttpFilter_DeprecatedV1) Unmarshal

func (m *HttpFilter_DeprecatedV1) Unmarshal(dAtA []byte) error

type MongoProxy

type MongoProxy struct {
	// The human readable prefix to use when emitting :ref:`statistics
	// <config_network_filters_mongo_proxy_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// The optional path to use for writing Mongo access logs. If not access log
	// path is specified no access logs will be written. Note that access log is
	// also gated :ref:`runtime <config_network_filters_mongo_proxy_runtime>`.
	AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
	// Inject a fixed delay before proxying a Mongo operation. Delays are
	// applied to the following MongoDB operations: Query, Insert, GetMore,
	// and KillCursors. Once an active delay is in progress, all incoming
	// data up until the timer event fires will be a part of the delay.
	Delay *envoy_api_v2_filter.FaultDelay `protobuf:"bytes,3,opt,name=delay" json:"delay,omitempty"`
}

func (*MongoProxy) Descriptor

func (*MongoProxy) Descriptor() ([]byte, []int)

func (*MongoProxy) GetAccessLog

func (m *MongoProxy) GetAccessLog() string

func (*MongoProxy) GetDelay

func (m *MongoProxy) GetDelay() *envoy_api_v2_filter.FaultDelay

func (*MongoProxy) GetStatPrefix

func (m *MongoProxy) GetStatPrefix() string

func (*MongoProxy) Marshal

func (m *MongoProxy) Marshal() (dAtA []byte, err error)

func (*MongoProxy) MarshalTo

func (m *MongoProxy) MarshalTo(dAtA []byte) (int, error)

func (*MongoProxy) ProtoMessage

func (*MongoProxy) ProtoMessage()

func (*MongoProxy) Reset

func (m *MongoProxy) Reset()

func (*MongoProxy) Size

func (m *MongoProxy) Size() (n int)

func (*MongoProxy) String

func (m *MongoProxy) String() string

func (*MongoProxy) Unmarshal

func (m *MongoProxy) Unmarshal(dAtA []byte) error

type RateLimit

type RateLimit struct {
	// The prefix to use when emitting :ref:`statistics <config_network_filters_rate_limit_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// The rate limit domain to use in the rate limit service request.
	Domain string `protobuf:"bytes,2,opt,name=domain,proto3" json:"domain,omitempty"`
	// The rate limit descriptor list to use in the rate limit service request.
	Descriptors []*envoy_api_v26.RateLimitDescriptor `protobuf:"bytes,3,rep,name=descriptors" json:"descriptors,omitempty"`
	// The timeout in milliseconds for the rate limit service RPC. If not
	// set, this defaults to 20ms.
	Timeout *google_protobuf2.Duration `protobuf:"bytes,4,opt,name=timeout" json:"timeout,omitempty"`
}

func (*RateLimit) Descriptor

func (*RateLimit) Descriptor() ([]byte, []int)

func (*RateLimit) GetDescriptors

func (m *RateLimit) GetDescriptors() []*envoy_api_v26.RateLimitDescriptor

func (*RateLimit) GetDomain

func (m *RateLimit) GetDomain() string

func (*RateLimit) GetStatPrefix

func (m *RateLimit) GetStatPrefix() string

func (*RateLimit) GetTimeout

func (m *RateLimit) GetTimeout() *google_protobuf2.Duration

func (*RateLimit) Marshal

func (m *RateLimit) Marshal() (dAtA []byte, err error)

func (*RateLimit) MarshalTo

func (m *RateLimit) MarshalTo(dAtA []byte) (int, error)

func (*RateLimit) ProtoMessage

func (*RateLimit) ProtoMessage()

func (*RateLimit) Reset

func (m *RateLimit) Reset()

func (*RateLimit) Size

func (m *RateLimit) Size() (n int)

func (*RateLimit) String

func (m *RateLimit) String() string

func (*RateLimit) Unmarshal

func (m *RateLimit) Unmarshal(dAtA []byte) error

type Rds

type Rds struct {
	// Configuration source specifier for RDS.
	ConfigSource envoy_api_v21.ConfigSource `protobuf:"bytes,1,opt,name=config_source,json=configSource" json:"config_source"`
	// The name of the route configuration. This name will be passed to the RDS
	// API. This allows an Envoy configuration with multiple HTTP listeners (and
	// associated HTTP connection manager filters) to use different route
	// configurations.
	RouteConfigName string `protobuf:"bytes,2,opt,name=route_config_name,json=routeConfigName,proto3" json:"route_config_name,omitempty"`
}

func (*Rds) Descriptor

func (*Rds) Descriptor() ([]byte, []int)

func (*Rds) GetConfigSource

func (m *Rds) GetConfigSource() envoy_api_v21.ConfigSource

func (*Rds) GetRouteConfigName

func (m *Rds) GetRouteConfigName() string

func (*Rds) Marshal

func (m *Rds) Marshal() (dAtA []byte, err error)

func (*Rds) MarshalTo

func (m *Rds) MarshalTo(dAtA []byte) (int, error)

func (*Rds) ProtoMessage

func (*Rds) ProtoMessage()

func (*Rds) Reset

func (m *Rds) Reset()

func (*Rds) Size

func (m *Rds) Size() (n int)

func (*Rds) String

func (m *Rds) String() string

func (*Rds) Unmarshal

func (m *Rds) Unmarshal(dAtA []byte) error

type RedisProxy

type RedisProxy struct {
	// The prefix to use when emitting :ref:`statistics <config_network_filters_redis_proxy_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// Name of cluster from cluster manager. See the :ref:`configuration section
	// <arch_overview_redis_configuration>` of the architecture overview for recommendations on
	// configuring the backing cluster.
	Cluster string `protobuf:"bytes,2,opt,name=cluster,proto3" json:"cluster,omitempty"`
	// Network settings for the connection pool to the upstream cluster.
	Settings *RedisProxy_ConnPoolSettings `protobuf:"bytes,3,opt,name=settings" json:"settings,omitempty"`
}

func (*RedisProxy) Descriptor

func (*RedisProxy) Descriptor() ([]byte, []int)

func (*RedisProxy) GetCluster

func (m *RedisProxy) GetCluster() string

func (*RedisProxy) GetSettings

func (m *RedisProxy) GetSettings() *RedisProxy_ConnPoolSettings

func (*RedisProxy) GetStatPrefix

func (m *RedisProxy) GetStatPrefix() string

func (*RedisProxy) Marshal

func (m *RedisProxy) Marshal() (dAtA []byte, err error)

func (*RedisProxy) MarshalTo

func (m *RedisProxy) MarshalTo(dAtA []byte) (int, error)

func (*RedisProxy) ProtoMessage

func (*RedisProxy) ProtoMessage()

func (*RedisProxy) Reset

func (m *RedisProxy) Reset()

func (*RedisProxy) Size

func (m *RedisProxy) Size() (n int)

func (*RedisProxy) String

func (m *RedisProxy) String() string

func (*RedisProxy) Unmarshal

func (m *RedisProxy) Unmarshal(dAtA []byte) error

type RedisProxy_ConnPoolSettings

type RedisProxy_ConnPoolSettings struct {
	// Per-operation timeout in milliseconds. The timer starts when the first
	// command of a pipeline is written to the backend connection. Each response received from Redis
	// resets the timer since it signifies that the next command is being processed by the backend.
	// The only exception to this behavior is when a connection to a backend is not yet established.
	// In that case, the connect timeout on the cluster will govern the timeout until the connection
	// is ready.
	OpTimeout *google_protobuf2.Duration `protobuf:"bytes,1,opt,name=op_timeout,json=opTimeout" json:"op_timeout,omitempty"`
}

Redis connection pool settings.

func (*RedisProxy_ConnPoolSettings) Descriptor

func (*RedisProxy_ConnPoolSettings) Descriptor() ([]byte, []int)

func (*RedisProxy_ConnPoolSettings) GetOpTimeout

func (*RedisProxy_ConnPoolSettings) Marshal

func (m *RedisProxy_ConnPoolSettings) Marshal() (dAtA []byte, err error)

func (*RedisProxy_ConnPoolSettings) MarshalTo

func (m *RedisProxy_ConnPoolSettings) MarshalTo(dAtA []byte) (int, error)

func (*RedisProxy_ConnPoolSettings) ProtoMessage

func (*RedisProxy_ConnPoolSettings) ProtoMessage()

func (*RedisProxy_ConnPoolSettings) Reset

func (m *RedisProxy_ConnPoolSettings) Reset()

func (*RedisProxy_ConnPoolSettings) Size

func (m *RedisProxy_ConnPoolSettings) Size() (n int)

func (*RedisProxy_ConnPoolSettings) String

func (m *RedisProxy_ConnPoolSettings) String() string

func (*RedisProxy_ConnPoolSettings) Unmarshal

func (m *RedisProxy_ConnPoolSettings) Unmarshal(dAtA []byte) error

type TcpProxy

type TcpProxy struct {
	// The prefix to use when emitting :ref:`statistics
	// <config_network_filters_tcp_proxy_stats>`.
	StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
	// The upstream cluster to connect to.
	//
	// .. note::
	//
	//  Once full filter chain matching is implemented in listeners, this field will become the only
	//  way to configure the target cluster. All other matching will be done via :ref:`filter chain
	//  matching rules <envoy_api_msg_FilterChainMatch>`. For very simple configurations, this field
	//  can still be used to select the cluster when no other matching rules are required. Otherwise,
	//  a :ref:`deprecated_v1 <envoy_api_field_filter.network.TcpProxy.deprecated_v1>` configuration
	//  is required to use more complex routing in the interim.
	//
	Cluster string `protobuf:"bytes,2,opt,name=cluster,proto3" json:"cluster,omitempty"`
	// The idle timeout for connections managed by the TCP proxy filter. The idle timeout
	// is defined as the period in which there are no bytes sent or received on either
	// the upstream or downstream connection. If not set, connections will never be closed
	// by the TCP proxy due to being idle.
	IdleTimeout *google_protobuf2.Duration `protobuf:"bytes,8,opt,name=idle_timeout,json=idleTimeout" json:"idle_timeout,omitempty"`
	// [#not-implemented-hide:] The idle timeout for connections managed by the TCP proxy
	// filter. The idle timeout is defined as the period in which there is no
	// active traffic. If not set, there is no idle timeout. When the idle timeout
	// is reached the connection will be closed. The distinction between
	// downstream_idle_timeout/upstream_idle_timeout provides a means to set
	// timeout based on the last byte sent on the downstream/upstream connection.
	DownstreamIdleTimeout *google_protobuf2.Duration `protobuf:"bytes,3,opt,name=downstream_idle_timeout,json=downstreamIdleTimeout" json:"downstream_idle_timeout,omitempty"`
	// [#not-implemented-hide:]
	UpstreamIdleTimeout *google_protobuf2.Duration `protobuf:"bytes,4,opt,name=upstream_idle_timeout,json=upstreamIdleTimeout" json:"upstream_idle_timeout,omitempty"`
	// Configuration for :ref:`access logs <arch_overview_access_logs>`
	// emitted by the this tcp_proxy.
	AccessLog []*envoy_api_v2_filter_accesslog.AccessLog `protobuf:"bytes,5,rep,name=access_log,json=accessLog" json:"access_log,omitempty"`
	// TCP Proxy filter configuration using deprecated V1 format. This is required for complex
	// routing until filter chain matching in the listener is implemented.
	DeprecatedV1 *TcpProxy_DeprecatedV1 `protobuf:"bytes,6,opt,name=deprecated_v1,json=deprecatedV1" json:"deprecated_v1,omitempty"`
	// The maximum number of unsuccessful connection attempts that will be made before
	// giving up. If the parameter is not specified, 1 connection attempt will be made.
	MaxConnectAttempts *google_protobuf.UInt32Value `protobuf:"bytes,7,opt,name=max_connect_attempts,json=maxConnectAttempts" json:"max_connect_attempts,omitempty"`
}

func (*TcpProxy) Descriptor

func (*TcpProxy) Descriptor() ([]byte, []int)

func (*TcpProxy) GetAccessLog

func (m *TcpProxy) GetAccessLog() []*envoy_api_v2_filter_accesslog.AccessLog

func (*TcpProxy) GetCluster

func (m *TcpProxy) GetCluster() string

func (*TcpProxy) GetDeprecatedV1

func (m *TcpProxy) GetDeprecatedV1() *TcpProxy_DeprecatedV1

func (*TcpProxy) GetDownstreamIdleTimeout

func (m *TcpProxy) GetDownstreamIdleTimeout() *google_protobuf2.Duration

func (*TcpProxy) GetIdleTimeout

func (m *TcpProxy) GetIdleTimeout() *google_protobuf2.Duration

func (*TcpProxy) GetMaxConnectAttempts

func (m *TcpProxy) GetMaxConnectAttempts() *google_protobuf.UInt32Value

func (*TcpProxy) GetStatPrefix

func (m *TcpProxy) GetStatPrefix() string

func (*TcpProxy) GetUpstreamIdleTimeout

func (m *TcpProxy) GetUpstreamIdleTimeout() *google_protobuf2.Duration

func (*TcpProxy) Marshal

func (m *TcpProxy) Marshal() (dAtA []byte, err error)

func (*TcpProxy) MarshalTo

func (m *TcpProxy) MarshalTo(dAtA []byte) (int, error)

func (*TcpProxy) ProtoMessage

func (*TcpProxy) ProtoMessage()

func (*TcpProxy) Reset

func (m *TcpProxy) Reset()

func (*TcpProxy) Size

func (m *TcpProxy) Size() (n int)

func (*TcpProxy) String

func (m *TcpProxy) String() string

func (*TcpProxy) Unmarshal

func (m *TcpProxy) Unmarshal(dAtA []byte) error

type TcpProxy_DeprecatedV1

type TcpProxy_DeprecatedV1 struct {
	// The route table for the filter. All filter instances must have a route
	// table, even if it is empty.
	Routes []*TcpProxy_DeprecatedV1_TCPRoute `protobuf:"bytes,1,rep,name=routes" json:"routes,omitempty"`
}

TCP Proxy filter configuration using V1 format, until Envoy gets the ability to match source/destination at the listener level (called :ref:`filter chain match <envoy_api_msg_FilterChainMatch>`).

func (*TcpProxy_DeprecatedV1) Descriptor

func (*TcpProxy_DeprecatedV1) Descriptor() ([]byte, []int)

func (*TcpProxy_DeprecatedV1) GetRoutes

func (*TcpProxy_DeprecatedV1) Marshal

func (m *TcpProxy_DeprecatedV1) Marshal() (dAtA []byte, err error)

func (*TcpProxy_DeprecatedV1) MarshalTo

func (m *TcpProxy_DeprecatedV1) MarshalTo(dAtA []byte) (int, error)

func (*TcpProxy_DeprecatedV1) ProtoMessage

func (*TcpProxy_DeprecatedV1) ProtoMessage()

func (*TcpProxy_DeprecatedV1) Reset

func (m *TcpProxy_DeprecatedV1) Reset()

func (*TcpProxy_DeprecatedV1) Size

func (m *TcpProxy_DeprecatedV1) Size() (n int)

func (*TcpProxy_DeprecatedV1) String

func (m *TcpProxy_DeprecatedV1) String() string

func (*TcpProxy_DeprecatedV1) Unmarshal

func (m *TcpProxy_DeprecatedV1) Unmarshal(dAtA []byte) error

type TcpProxy_DeprecatedV1_TCPRoute

type TcpProxy_DeprecatedV1_TCPRoute struct {
	// The cluster to connect to when a the downstream network connection
	// matches the specified criteria.
	Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
	// An optional list of IP address subnets in the form
	// “ip_address/xx”. The criteria is satisfied if the destination IP
	// address of the downstream connection is contained in at least one of
	// the specified subnets. If the parameter is not specified or the list
	// is empty, the destination IP address is ignored. The destination IP
	// address of the downstream connection might be different from the
	// addresses on which the proxy is listening if the connection has been
	// redirected.
	DestinationIpList []*envoy_api_v2.CidrRange `protobuf:"bytes,2,rep,name=destination_ip_list,json=destinationIpList" json:"destination_ip_list,omitempty"`
	// An optional string containing a comma-separated list of port numbers
	// or ranges. The criteria is satisfied if the destination port of the
	// downstream connection is contained in at least one of the specified
	// ranges. If the parameter is not specified, the destination port is
	// ignored. The destination port address of the downstream connection
	// might be different from the port on which the proxy is listening if
	// the connection has been redirected.
	DestinationPorts string `protobuf:"bytes,3,opt,name=destination_ports,json=destinationPorts,proto3" json:"destination_ports,omitempty"`
	// An optional list of IP address subnets in the form
	// “ip_address/xx”. The criteria is satisfied if the source IP address
	// of the downstream connection is contained in at least one of the
	// specified subnets. If the parameter is not specified or the list is
	// empty, the source IP address is ignored.
	SourceIpList []*envoy_api_v2.CidrRange `protobuf:"bytes,4,rep,name=source_ip_list,json=sourceIpList" json:"source_ip_list,omitempty"`
	// An optional string containing a comma-separated list of port numbers
	// or ranges. The criteria is satisfied if the source port of the
	// downstream connection is contained in at least one of the specified
	// ranges. If the parameter is not specified, the source port is
	// ignored.
	SourcePorts string `protobuf:"bytes,5,opt,name=source_ports,json=sourcePorts,proto3" json:"source_ports,omitempty"`
}

A TCP proxy route consists of a set of optional L4 criteria and the name of a cluster. If a downstream connection matches all the specified criteria, the cluster in the route is used for the corresponding upstream connection. Routes are tried in the order specified until a match is found. If no match is found, the connection is closed. A route with no criteria is valid and always produces a match.

func (*TcpProxy_DeprecatedV1_TCPRoute) Descriptor

func (*TcpProxy_DeprecatedV1_TCPRoute) Descriptor() ([]byte, []int)

func (*TcpProxy_DeprecatedV1_TCPRoute) GetCluster

func (m *TcpProxy_DeprecatedV1_TCPRoute) GetCluster() string

func (*TcpProxy_DeprecatedV1_TCPRoute) GetDestinationIpList

func (m *TcpProxy_DeprecatedV1_TCPRoute) GetDestinationIpList() []*envoy_api_v2.CidrRange

func (*TcpProxy_DeprecatedV1_TCPRoute) GetDestinationPorts

func (m *TcpProxy_DeprecatedV1_TCPRoute) GetDestinationPorts() string

func (*TcpProxy_DeprecatedV1_TCPRoute) GetSourceIpList

func (m *TcpProxy_DeprecatedV1_TCPRoute) GetSourceIpList() []*envoy_api_v2.CidrRange

func (*TcpProxy_DeprecatedV1_TCPRoute) GetSourcePorts

func (m *TcpProxy_DeprecatedV1_TCPRoute) GetSourcePorts() string

func (*TcpProxy_DeprecatedV1_TCPRoute) Marshal

func (m *TcpProxy_DeprecatedV1_TCPRoute) Marshal() (dAtA []byte, err error)

func (*TcpProxy_DeprecatedV1_TCPRoute) MarshalTo

func (m *TcpProxy_DeprecatedV1_TCPRoute) MarshalTo(dAtA []byte) (int, error)

func (*TcpProxy_DeprecatedV1_TCPRoute) ProtoMessage

func (*TcpProxy_DeprecatedV1_TCPRoute) ProtoMessage()

func (*TcpProxy_DeprecatedV1_TCPRoute) Reset

func (m *TcpProxy_DeprecatedV1_TCPRoute) Reset()

func (*TcpProxy_DeprecatedV1_TCPRoute) Size

func (m *TcpProxy_DeprecatedV1_TCPRoute) Size() (n int)

func (*TcpProxy_DeprecatedV1_TCPRoute) String

func (*TcpProxy_DeprecatedV1_TCPRoute) Unmarshal

func (m *TcpProxy_DeprecatedV1_TCPRoute) Unmarshal(dAtA []byte) error

Jump to